"""Pokemon data for the faker_pokemon provider.

Auto-generated by scripts/update_data.py from PokeAPI (https://pokeapi.co/).
Do not edit manually.
"""

POKEMON_NAMES: tuple[str, ...] = (
    "Bulbasaur",
    "Ivysaur",
    "Venusaur",
    "Charmander",
    "Charmeleon",
    "Charizard",
    "Squirtle",
    "Wartortle",
    "Blastoise",
    "Caterpie",
    "Metapod",
    "Butterfree",
    "Weedle",
    "Kakuna",
    "Beedrill",
    "Pidgey",
    "Pidgeotto",
    "Pidgeot",
    "Rattata",
    "Raticate",
    "Spearow",
    "Fearow",
    "Ekans",
    "Arbok",
    "Pikachu",
    "Raichu",
    "Sandshrew",
    "Sandslash",
    "Nidoran-f",
    "Nidorina",
    "Nidoqueen",
    "Nidoran-m",
    "Nidorino",
    "Nidoking",
    "Clefairy",
    "Clefable",
    "Vulpix",
    "Ninetales",
    "Jigglypuff",
    "Wigglytuff",
    "Zubat",
    "Golbat",
    "Oddish",
    "Gloom",
    "Vileplume",
    "Paras",
    "Parasect",
    "Venonat",
    "Venomoth",
    "Diglett",
    "Dugtrio",
    "Meowth",
    "Persian",
    "Psyduck",
    "Golduck",
    "Mankey",
    "Primeape",
    "Growlithe",
    "Arcanine",
    "Poliwag",
    "Poliwhirl",
    "Poliwrath",
    "Abra",
    "Kadabra",
    "Alakazam",
    "Machop",
    "Machoke",
    "Machamp",
    "Bellsprout",
    "Weepinbell",
    "Victreebel",
    "Tentacool",
    "Tentacruel",
    "Geodude",
    "Graveler",
    "Golem",
    "Ponyta",
    "Rapidash",
    "Slowpoke",
    "Slowbro",
    "Magnemite",
    "Magneton",
    "Farfetchd",
    "Doduo",
    "Dodrio",
    "Seel",
    "Dewgong",
    "Grimer",
    "Muk",
    "Shellder",
    "Cloyster",
    "Gastly",
    "Haunter",
    "Gengar",
    "Onix",
    "Drowzee",
    "Hypno",
    "Krabby",
    "Kingler",
    "Voltorb",
    "Electrode",
    "Exeggcute",
    "Exeggutor",
    "Cubone",
    "Marowak",
    "Hitmonlee",
    "Hitmonchan",
    "Lickitung",
    "Koffing",
    "Weezing",
    "Rhyhorn",
    "Rhydon",
    "Chansey",
    "Tangela",
    "Kangaskhan",
    "Horsea",
    "Seadra",
    "Goldeen",
    "Seaking",
    "Staryu",
    "Starmie",
    "Mr-mime",
    "Scyther",
    "Jynx",
    "Electabuzz",
    "Magmar",
    "Pinsir",
    "Tauros",
    "Magikarp",
    "Gyarados",
    "Lapras",
    "Ditto",
    "Eevee",
    "Vaporeon",
    "Jolteon",
    "Flareon",
    "Porygon",
    "Omanyte",
    "Omastar",
    "Kabuto",
    "Kabutops",
    "Aerodactyl",
    "Snorlax",
    "Articuno",
    "Zapdos",
    "Moltres",
    "Dratini",
    "Dragonair",
    "Dragonite",
    "Mewtwo",
    "Mew",
    "Chikorita",
    "Bayleef",
    "Meganium",
    "Cyndaquil",
    "Quilava",
    "Typhlosion",
    "Totodile",
    "Croconaw",
    "Feraligatr",
    "Sentret",
    "Furret",
    "Hoothoot",
    "Noctowl",
    "Ledyba",
    "Ledian",
    "Spinarak",
    "Ariados",
    "Crobat",
    "Chinchou",
    "Lanturn",
    "Pichu",
    "Cleffa",
    "Igglybuff",
    "Togepi",
    "Togetic",
    "Natu",
    "Xatu",
    "Mareep",
    "Flaaffy",
    "Ampharos",
    "Bellossom",
    "Marill",
    "Azumarill",
    "Sudowoodo",
    "Politoed",
    "Hoppip",
    "Skiploom",
    "Jumpluff",
    "Aipom",
    "Sunkern",
    "Sunflora",
    "Yanma",
    "Wooper",
    "Quagsire",
    "Espeon",
    "Umbreon",
    "Murkrow",
    "Slowking",
    "Misdreavus",
    "Unown",
    "Wobbuffet",
    "Girafarig",
    "Pineco",
    "Forretress",
    "Dunsparce",
    "Gligar",
    "Steelix",
    "Snubbull",
    "Granbull",
    "Qwilfish",
    "Scizor",
    "Shuckle",
    "Heracross",
    "Sneasel",
    "Teddiursa",
    "Ursaring",
    "Slugma",
    "Magcargo",
    "Swinub",
    "Piloswine",
    "Corsola",
    "Remoraid",
    "Octillery",
    "Delibird",
    "Mantine",
    "Skarmory",
    "Houndour",
    "Houndoom",
    "Kingdra",
    "Phanpy",
    "Donphan",
    "Porygon2",
    "Stantler",
    "Smeargle",
    "Tyrogue",
    "Hitmontop",
    "Smoochum",
    "Elekid",
    "Magby",
    "Miltank",
    "Blissey",
    "Raikou",
    "Entei",
    "Suicune",
    "Larvitar",
    "Pupitar",
    "Tyranitar",
    "Lugia",
    "Ho-oh",
    "Celebi",
    "Treecko",
    "Grovyle",
    "Sceptile",
    "Torchic",
    "Combusken",
    "Blaziken",
    "Mudkip",
    "Marshtomp",
    "Swampert",
    "Poochyena",
    "Mightyena",
    "Zigzagoon",
    "Linoone",
    "Wurmple",
    "Silcoon",
    "Beautifly",
    "Cascoon",
    "Dustox",
    "Lotad",
    "Lombre",
    "Ludicolo",
    "Seedot",
    "Nuzleaf",
    "Shiftry",
    "Taillow",
    "Swellow",
    "Wingull",
    "Pelipper",
    "Ralts",
    "Kirlia",
    "Gardevoir",
    "Surskit",
    "Masquerain",
    "Shroomish",
    "Breloom",
    "Slakoth",
    "Vigoroth",
    "Slaking",
    "Nincada",
    "Ninjask",
    "Shedinja",
    "Whismur",
    "Loudred",
    "Exploud",
    "Makuhita",
    "Hariyama",
    "Azurill",
    "Nosepass",
    "Skitty",
    "Delcatty",
    "Sableye",
    "Mawile",
    "Aron",
    "Lairon",
    "Aggron",
    "Meditite",
    "Medicham",
    "Electrike",
    "Manectric",
    "Plusle",
    "Minun",
    "Volbeat",
    "Illumise",
    "Roselia",
    "Gulpin",
    "Swalot",
    "Carvanha",
    "Sharpedo",
    "Wailmer",
    "Wailord",
    "Numel",
    "Camerupt",
    "Torkoal",
    "Spoink",
    "Grumpig",
    "Spinda",
    "Trapinch",
    "Vibrava",
    "Flygon",
    "Cacnea",
    "Cacturne",
    "Swablu",
    "Altaria",
    "Zangoose",
    "Seviper",
    "Lunatone",
    "Solrock",
    "Barboach",
    "Whiscash",
    "Corphish",
    "Crawdaunt",
    "Baltoy",
    "Claydol",
    "Lileep",
    "Cradily",
    "Anorith",
    "Armaldo",
    "Feebas",
    "Milotic",
    "Castform",
    "Kecleon",
    "Shuppet",
    "Banette",
    "Duskull",
    "Dusclops",
    "Tropius",
    "Chimecho",
    "Absol",
    "Wynaut",
    "Snorunt",
    "Glalie",
    "Spheal",
    "Sealeo",
    "Walrein",
    "Clamperl",
    "Huntail",
    "Gorebyss",
    "Relicanth",
    "Luvdisc",
    "Bagon",
    "Shelgon",
    "Salamence",
    "Beldum",
    "Metang",
    "Metagross",
    "Regirock",
    "Regice",
    "Registeel",
    "Latias",
    "Latios",
    "Kyogre",
    "Groudon",
    "Rayquaza",
    "Jirachi",
    "Deoxys",
    "Turtwig",
    "Grotle",
    "Torterra",
    "Chimchar",
    "Monferno",
    "Infernape",
    "Piplup",
    "Prinplup",
    "Empoleon",
    "Starly",
    "Staravia",
    "Staraptor",
    "Bidoof",
    "Bibarel",
    "Kricketot",
    "Kricketune",
    "Shinx",
    "Luxio",
    "Luxray",
    "Budew",
    "Roserade",
    "Cranidos",
    "Rampardos",
    "Shieldon",
    "Bastiodon",
    "Burmy",
    "Wormadam",
    "Mothim",
    "Combee",
    "Vespiquen",
    "Pachirisu",
    "Buizel",
    "Floatzel",
    "Cherubi",
    "Cherrim",
    "Shellos",
    "Gastrodon",
    "Ambipom",
    "Drifloon",
    "Drifblim",
    "Buneary",
    "Lopunny",
    "Mismagius",
    "Honchkrow",
    "Glameow",
    "Purugly",
    "Chingling",
    "Stunky",
    "Skuntank",
    "Bronzor",
    "Bronzong",
    "Bonsly",
    "Mime-jr",
    "Happiny",
    "Chatot",
    "Spiritomb",
    "Gible",
    "Gabite",
    "Garchomp",
    "Munchlax",
    "Riolu",
    "Lucario",
    "Hippopotas",
    "Hippowdon",
    "Skorupi",
    "Drapion",
    "Croagunk",
    "Toxicroak",
    "Carnivine",
    "Finneon",
    "Lumineon",
    "Mantyke",
    "Snover",
    "Abomasnow",
    "Weavile",
    "Magnezone",
    "Lickilicky",
    "Rhyperior",
    "Tangrowth",
    "Electivire",
    "Magmortar",
    "Togekiss",
    "Yanmega",
    "Leafeon",
    "Glaceon",
    "Gliscor",
    "Mamoswine",
    "Porygon-z",
    "Gallade",
    "Probopass",
    "Dusknoir",
    "Froslass",
    "Rotom",
    "Uxie",
    "Mesprit",
    "Azelf",
    "Dialga",
    "Palkia",
    "Heatran",
    "Regigigas",
    "Giratina",
    "Cresselia",
    "Phione",
    "Manaphy",
    "Darkrai",
    "Shaymin",
    "Arceus",
    "Victini",
    "Snivy",
    "Servine",
    "Serperior",
    "Tepig",
    "Pignite",
    "Emboar",
    "Oshawott",
    "Dewott",
    "Samurott",
    "Patrat",
    "Watchog",
    "Lillipup",
    "Herdier",
    "Stoutland",
    "Purrloin",
    "Liepard",
    "Pansage",
    "Simisage",
    "Pansear",
    "Simisear",
    "Panpour",
    "Simipour",
    "Munna",
    "Musharna",
    "Pidove",
    "Tranquill",
    "Unfezant",
    "Blitzle",
    "Zebstrika",
    "Roggenrola",
    "Boldore",
    "Gigalith",
    "Woobat",
    "Swoobat",
    "Drilbur",
    "Excadrill",
    "Audino",
    "Timburr",
    "Gurdurr",
    "Conkeldurr",
    "Tympole",
    "Palpitoad",
    "Seismitoad",
    "Throh",
    "Sawk",
    "Sewaddle",
    "Swadloon",
    "Leavanny",
    "Venipede",
    "Whirlipede",
    "Scolipede",
    "Cottonee",
    "Whimsicott",
    "Petilil",
    "Lilligant",
    "Basculin",
    "Sandile",
    "Krokorok",
    "Krookodile",
    "Darumaka",
    "Darmanitan",
    "Maractus",
    "Dwebble",
    "Crustle",
    "Scraggy",
    "Scrafty",
    "Sigilyph",
    "Yamask",
    "Cofagrigus",
    "Tirtouga",
    "Carracosta",
    "Archen",
    "Archeops",
    "Trubbish",
    "Garbodor",
    "Zorua",
    "Zoroark",
    "Minccino",
    "Cinccino",
    "Gothita",
    "Gothorita",
    "Gothitelle",
    "Solosis",
    "Duosion",
    "Reuniclus",
    "Ducklett",
    "Swanna",
    "Vanillite",
    "Vanillish",
    "Vanilluxe",
    "Deerling",
    "Sawsbuck",
    "Emolga",
    "Karrablast",
    "Escavalier",
    "Foongus",
    "Amoonguss",
    "Frillish",
    "Jellicent",
    "Alomomola",
    "Joltik",
    "Galvantula",
    "Ferroseed",
    "Ferrothorn",
    "Klink",
    "Klang",
    "Klinklang",
    "Tynamo",
    "Eelektrik",
    "Eelektross",
    "Elgyem",
    "Beheeyem",
    "Litwick",
    "Lampent",
    "Chandelure",
    "Axew",
    "Fraxure",
    "Haxorus",
    "Cubchoo",
    "Beartic",
    "Cryogonal",
    "Shelmet",
    "Accelgor",
    "Stunfisk",
    "Mienfoo",
    "Mienshao",
    "Druddigon",
    "Golett",
    "Golurk",
    "Pawniard",
    "Bisharp",
    "Bouffalant",
    "Rufflet",
    "Braviary",
    "Vullaby",
    "Mandibuzz",
    "Heatmor",
    "Durant",
    "Deino",
    "Zweilous",
    "Hydreigon",
    "Larvesta",
    "Volcarona",
    "Cobalion",
    "Terrakion",
    "Virizion",
    "Tornadus",
    "Thundurus",
    "Reshiram",
    "Zekrom",
    "Landorus",
    "Kyurem",
    "Keldeo",
    "Meloetta",
    "Genesect",
    "Chespin",
    "Quilladin",
    "Chesnaught",
    "Fennekin",
    "Braixen",
    "Delphox",
    "Froakie",
    "Frogadier",
    "Greninja",
    "Bunnelby",
    "Diggersby",
    "Fletchling",
    "Fletchinder",
    "Talonflame",
    "Scatterbug",
    "Spewpa",
    "Vivillon",
    "Litleo",
    "Pyroar",
    "Flabebe",
    "Floette",
    "Florges",
    "Skiddo",
    "Gogoat",
    "Pancham",
    "Pangoro",
    "Furfrou",
    "Espurr",
    "Meowstic",
    "Honedge",
    "Doublade",
    "Aegislash",
    "Spritzee",
    "Aromatisse",
    "Swirlix",
    "Slurpuff",
    "Inkay",
    "Malamar",
    "Binacle",
    "Barbaracle",
    "Skrelp",
    "Dragalge",
    "Clauncher",
    "Clawitzer",
    "Helioptile",
    "Heliolisk",
    "Tyrunt",
    "Tyrantrum",
    "Amaura",
    "Aurorus",
    "Sylveon",
    "Hawlucha",
    "Dedenne",
    "Carbink",
    "Goomy",
    "Sliggoo",
    "Goodra",
    "Klefki",
    "Phantump",
    "Trevenant",
    "Pumpkaboo",
    "Gourgeist",
    "Bergmite",
    "Avalugg",
    "Noibat",
    "Noivern",
    "Xerneas",
    "Yveltal",
    "Zygarde",
    "Diancie",
    "Hoopa",
    "Volcanion",
    "Rowlet",
    "Dartrix",
    "Decidueye",
    "Litten",
    "Torracat",
    "Incineroar",
    "Popplio",
    "Brionne",
    "Primarina",
    "Pikipek",
    "Trumbeak",
    "Toucannon",
    "Yungoos",
    "Gumshoos",
    "Grubbin",
    "Charjabug",
    "Vikavolt",
    "Crabrawler",
    "Crabominable",
    "Oricorio",
    "Cutiefly",
    "Ribombee",
    "Rockruff",
    "Lycanroc",
    "Wishiwashi",
    "Mareanie",
    "Toxapex",
    "Mudbray",
    "Mudsdale",
    "Dewpider",
    "Araquanid",
    "Fomantis",
    "Lurantis",
    "Morelull",
    "Shiinotic",
    "Salandit",
    "Salazzle",
    "Stufful",
    "Bewear",
    "Bounsweet",
    "Steenee",
    "Tsareena",
    "Comfey",
    "Oranguru",
    "Passimian",
    "Wimpod",
    "Golisopod",
    "Sandygast",
    "Palossand",
    "Pyukumuku",
    "Type-null",
    "Silvally",
    "Minior",
    "Komala",
    "Turtonator",
    "Togedemaru",
    "Mimikyu",
    "Bruxish",
    "Drampa",
    "Dhelmise",
    "Jangmo-o",
    "Hakamo-o",
    "Kommo-o",
    "Tapu-koko",
    "Tapu-lele",
    "Tapu-bulu",
    "Tapu-fini",
    "Cosmog",
    "Cosmoem",
    "Solgaleo",
    "Lunala",
    "Nihilego",
    "Buzzwole",
    "Pheromosa",
    "Xurkitree",
    "Celesteela",
    "Kartana",
    "Guzzlord",
    "Necrozma",
    "Magearna",
    "Marshadow",
    "Poipole",
    "Naganadel",
    "Stakataka",
    "Blacephalon",
    "Zeraora",
    "Meltan",
    "Melmetal",
    "Grookey",
    "Thwackey",
    "Rillaboom",
    "Scorbunny",
    "Raboot",
    "Cinderace",
    "Sobble",
    "Drizzile",
    "Inteleon",
    "Skwovet",
    "Greedent",
    "Rookidee",
    "Corvisquire",
    "Corviknight",
    "Blipbug",
    "Dottler",
    "Orbeetle",
    "Nickit",
    "Thievul",
    "Gossifleur",
    "Eldegoss",
    "Wooloo",
    "Dubwool",
    "Chewtle",
    "Drednaw",
    "Yamper",
    "Boltund",
    "Rolycoly",
    "Carkol",
    "Coalossal",
    "Applin",
    "Flapple",
    "Appletun",
    "Silicobra",
    "Sandaconda",
    "Cramorant",
    "Arrokuda",
    "Barraskewda",
    "Toxel",
    "Toxtricity",
    "Sizzlipede",
    "Centiskorch",
    "Clobbopus",
    "Grapploct",
    "Sinistea",
    "Polteageist",
    "Hatenna",
    "Hattrem",
    "Hatterene",
    "Impidimp",
    "Morgrem",
    "Grimmsnarl",
    "Obstagoon",
    "Perrserker",
    "Cursola",
    "Sirfetchd",
    "Mr-rime",
    "Runerigus",
    "Milcery",
    "Alcremie",
    "Falinks",
    "Pincurchin",
    "Snom",
    "Frosmoth",
    "Stonjourner",
    "Eiscue",
    "Indeedee",
    "Morpeko",
    "Cufant",
    "Copperajah",
    "Dracozolt",
    "Arctozolt",
    "Dracovish",
    "Arctovish",
    "Duraludon",
    "Dreepy",
    "Drakloak",
    "Dragapult",
    "Zacian",
    "Zamazenta",
    "Eternatus",
    "Kubfu",
    "Urshifu",
    "Zarude",
    "Regieleki",
    "Regidrago",
    "Glastrier",
    "Spectrier",
    "Calyrex",
    "Wyrdeer",
    "Kleavor",
    "Ursaluna",
    "Basculegion",
    "Sneasler",
    "Overqwil",
    "Enamorus",
    "Sprigatito",
    "Floragato",
    "Meowscarada",
    "Fuecoco",
    "Crocalor",
    "Skeledirge",
    "Quaxly",
    "Quaxwell",
    "Quaquaval",
    "Lechonk",
    "Oinkologne",
    "Tarountula",
    "Spidops",
    "Nymble",
    "Lokix",
    "Pawmi",
    "Pawmo",
    "Pawmot",
    "Tandemaus",
    "Maushold",
    "Fidough",
    "Dachsbun",
    "Smoliv",
    "Dolliv",
    "Arboliva",
    "Squawkabilly",
    "Nacli",
    "Naclstack",
    "Garganacl",
    "Charcadet",
    "Armarouge",
    "Ceruledge",
    "Tadbulb",
    "Bellibolt",
    "Wattrel",
    "Kilowattrel",
    "Maschiff",
    "Mabosstiff",
    "Shroodle",
    "Grafaiai",
    "Bramblin",
    "Brambleghast",
    "Toedscool",
    "Toedscruel",
    "Klawf",
    "Capsakid",
    "Scovillain",
    "Rellor",
    "Rabsca",
    "Flittle",
    "Espathra",
    "Tinkatink",
    "Tinkatuff",
    "Tinkaton",
    "Wiglett",
    "Wugtrio",
    "Bombirdier",
    "Finizen",
    "Palafin",
    "Varoom",
    "Revavroom",
    "Cyclizar",
    "Orthworm",
    "Glimmet",
    "Glimmora",
    "Greavard",
    "Houndstone",
    "Flamigo",
    "Cetoddle",
    "Cetitan",
    "Veluza",
    "Dondozo",
    "Tatsugiri",
    "Annihilape",
    "Clodsire",
    "Farigiraf",
    "Dudunsparce",
    "Kingambit",
    "Great-tusk",
    "Scream-tail",
    "Brute-bonnet",
    "Flutter-mane",
    "Slither-wing",
    "Sandy-shocks",
    "Iron-treads",
    "Iron-bundle",
    "Iron-hands",
    "Iron-jugulis",
    "Iron-moth",
    "Iron-thorns",
    "Frigibax",
    "Arctibax",
    "Baxcalibur",
    "Gimmighoul",
    "Gholdengo",
    "Wo-chien",
    "Chien-pao",
    "Ting-lu",
    "Chi-yu",
    "Roaring-moon",
    "Iron-valiant",
    "Koraidon",
    "Miraidon",
    "Walking-wake",
    "Iron-leaves",
    "Dipplin",
    "Poltchageist",
    "Sinistcha",
    "Okidogi",
    "Munkidori",
    "Fezandipiti",
    "Ogerpon",
    "Archaludon",
    "Hydrapple",
    "Gouging-fire",
    "Raging-bolt",
    "Iron-boulder",
    "Iron-crown",
    "Terapagos",
    "Pecharunt",
)

POKEMON_TYPES: tuple[str, ...] = (
    "Normal",
    "Fighting",
    "Flying",
    "Poison",
    "Ground",
    "Rock",
    "Bug",
    "Ghost",
    "Steel",
    "Fire",
    "Water",
    "Grass",
    "Electric",
    "Psychic",
    "Ice",
    "Dragon",
    "Dark",
    "Fairy",
    "Stellar",
    "Unknown",
    "Shadow",
)

POKEMON_MOVES: tuple[str, ...] = (
    "Pound",
    "Karate Chop",
    "Double Slap",
    "Comet Punch",
    "Mega Punch",
    "Pay Day",
    "Fire Punch",
    "Ice Punch",
    "Thunder Punch",
    "Scratch",
    "Vice Grip",
    "Guillotine",
    "Razor Wind",
    "Swords Dance",
    "Cut",
    "Gust",
    "Wing Attack",
    "Whirlwind",
    "Fly",
    "Bind",
    "Slam",
    "Vine Whip",
    "Stomp",
    "Double Kick",
    "Mega Kick",
    "Jump Kick",
    "Rolling Kick",
    "Sand Attack",
    "Headbutt",
    "Horn Attack",
    "Fury Attack",
    "Horn Drill",
    "Tackle",
    "Body Slam",
    "Wrap",
    "Take Down",
    "Thrash",
    "Double Edge",
    "Tail Whip",
    "Poison Sting",
    "Twineedle",
    "Pin Missile",
    "Leer",
    "Bite",
    "Growl",
    "Roar",
    "Sing",
    "Supersonic",
    "Sonic Boom",
    "Disable",
    "Acid",
    "Ember",
    "Flamethrower",
    "Mist",
    "Water Gun",
    "Hydro Pump",
    "Surf",
    "Ice Beam",
    "Blizzard",
    "Psybeam",
    "Bubble Beam",
    "Aurora Beam",
    "Hyper Beam",
    "Peck",
    "Drill Peck",
    "Submission",
    "Low Kick",
    "Counter",
    "Seismic Toss",
    "Strength",
    "Absorb",
    "Mega Drain",
    "Leech Seed",
    "Growth",
    "Razor Leaf",
    "Solar Beam",
    "Poison Powder",
    "Stun Spore",
    "Sleep Powder",
    "Petal Dance",
    "String Shot",
    "Dragon Rage",
    "Fire Spin",
    "Thunder Shock",
    "Thunderbolt",
    "Thunder Wave",
    "Thunder",
    "Rock Throw",
    "Earthquake",
    "Fissure",
    "Dig",
    "Toxic",
    "Confusion",
    "Psychic",
    "Hypnosis",
    "Meditate",
    "Agility",
    "Quick Attack",
    "Rage",
    "Teleport",
    "Night Shade",
    "Mimic",
    "Screech",
    "Double Team",
    "Recover",
    "Harden",
    "Minimize",
    "Smokescreen",
    "Confuse Ray",
    "Withdraw",
    "Defense Curl",
    "Barrier",
    "Light Screen",
    "Haze",
    "Reflect",
    "Focus Energy",
    "Bide",
    "Metronome",
    "Mirror Move",
    "Self Destruct",
    "Egg Bomb",
    "Lick",
    "Smog",
    "Sludge",
    "Bone Club",
    "Fire Blast",
    "Waterfall",
    "Clamp",
    "Swift",
    "Skull Bash",
    "Spike Cannon",
    "Constrict",
    "Amnesia",
    "Kinesis",
    "Soft Boiled",
    "High Jump Kick",
    "Glare",
    "Dream Eater",
    "Poison Gas",
    "Barrage",
    "Leech Life",
    "Lovely Kiss",
    "Sky Attack",
    "Transform",
    "Bubble",
    "Dizzy Punch",
    "Spore",
    "Flash",
    "Psywave",
    "Splash",
    "Acid Armor",
    "Crabhammer",
    "Explosion",
    "Fury Swipes",
    "Bonemerang",
    "Rest",
    "Rock Slide",
    "Hyper Fang",
    "Sharpen",
    "Conversion",
    "Tri Attack",
    "Super Fang",
    "Slash",
    "Substitute",
    "Struggle",
    "Sketch",
    "Triple Kick",
    "Thief",
    "Spider Web",
    "Mind Reader",
    "Nightmare",
    "Flame Wheel",
    "Snore",
    "Curse",
    "Flail",
    "Conversion 2",
    "Aeroblast",
    "Cotton Spore",
    "Reversal",
    "Spite",
    "Powder Snow",
    "Protect",
    "Mach Punch",
    "Scary Face",
    "Feint Attack",
    "Sweet Kiss",
    "Belly Drum",
    "Sludge Bomb",
    "Mud Slap",
    "Octazooka",
    "Spikes",
    "Zap Cannon",
    "Foresight",
    "Destiny Bond",
    "Perish Song",
    "Icy Wind",
    "Detect",
    "Bone Rush",
    "Lock On",
    "Outrage",
    "Sandstorm",
    "Giga Drain",
    "Endure",
    "Charm",
    "Rollout",
    "False Swipe",
    "Swagger",
    "Milk Drink",
    "Spark",
    "Fury Cutter",
    "Steel Wing",
    "Mean Look",
    "Attract",
    "Sleep Talk",
    "Heal Bell",
    "Return",
    "Present",
    "Frustration",
    "Safeguard",
    "Pain Split",
    "Sacred Fire",
    "Magnitude",
    "Dynamic Punch",
    "Megahorn",
    "Dragon Breath",
    "Baton Pass",
    "Encore",
    "Pursuit",
    "Rapid Spin",
    "Sweet Scent",
    "Iron Tail",
    "Metal Claw",
    "Vital Throw",
    "Morning Sun",
    "Synthesis",
    "Moonlight",
    "Hidden Power",
    "Cross Chop",
    "Twister",
    "Rain Dance",
    "Sunny Day",
    "Crunch",
    "Mirror Coat",
    "Psych Up",
    "Extreme Speed",
    "Ancient Power",
    "Shadow Ball",
    "Future Sight",
    "Rock Smash",
    "Whirlpool",
    "Beat Up",
    "Fake Out",
    "Uproar",
    "Stockpile",
    "Spit Up",
    "Swallow",
    "Heat Wave",
    "Hail",
    "Torment",
    "Flatter",
    "Will O Wisp",
    "Memento",
    "Facade",
    "Focus Punch",
    "Smelling Salts",
    "Follow Me",
    "Nature Power",
    "Charge",
    "Taunt",
    "Helping Hand",
    "Trick",
    "Role Play",
    "Wish",
    "Assist",
    "Ingrain",
    "Superpower",
    "Magic Coat",
    "Recycle",
    "Revenge",
    "Brick Break",
    "Yawn",
    "Knock Off",
    "Endeavor",
    "Eruption",
    "Skill Swap",
    "Imprison",
    "Refresh",
    "Grudge",
    "Snatch",
    "Secret Power",
    "Dive",
    "Arm Thrust",
    "Camouflage",
    "Tail Glow",
    "Luster Purge",
    "Mist Ball",
    "Feather Dance",
    "Teeter Dance",
    "Blaze Kick",
    "Mud Sport",
    "Ice Ball",
    "Needle Arm",
    "Slack Off",
    "Hyper Voice",
    "Poison Fang",
    "Crush Claw",
    "Blast Burn",
    "Hydro Cannon",
    "Meteor Mash",
    "Astonish",
    "Weather Ball",
    "Aromatherapy",
    "Fake Tears",
    "Air Cutter",
    "Overheat",
    "Odor Sleuth",
    "Rock Tomb",
    "Silver Wind",
    "Metal Sound",
    "Grass Whistle",
    "Tickle",
    "Cosmic Power",
    "Water Spout",
    "Signal Beam",
    "Shadow Punch",
    "Extrasensory",
    "Sky Uppercut",
    "Sand Tomb",
    "Sheer Cold",
    "Muddy Water",
    "Bullet Seed",
    "Aerial Ace",
    "Icicle Spear",
    "Iron Defense",
    "Block",
    "Howl",
    "Dragon Claw",
    "Frenzy Plant",
    "Bulk Up",
    "Bounce",
    "Mud Shot",
    "Poison Tail",
    "Covet",
    "Volt Tackle",
    "Magical Leaf",
    "Water Sport",
    "Calm Mind",
    "Leaf Blade",
    "Dragon Dance",
    "Rock Blast",
    "Shock Wave",
    "Water Pulse",
    "Doom Desire",
    "Psycho Boost",
    "Roost",
    "Gravity",
    "Miracle Eye",
    "Wake Up Slap",
    "Hammer Arm",
    "Gyro Ball",
    "Healing Wish",
    "Brine",
    "Natural Gift",
    "Feint",
    "Pluck",
    "Tailwind",
    "Acupressure",
    "Metal Burst",
    "U Turn",
    "Close Combat",
    "Payback",
    "Assurance",
    "Embargo",
    "Fling",
    "Psycho Shift",
    "Trump Card",
    "Heal Block",
    "Wring Out",
    "Power Trick",
    "Gastro Acid",
    "Lucky Chant",
    "Me First",
    "Copycat",
    "Power Swap",
    "Guard Swap",
    "Punishment",
    "Last Resort",
    "Worry Seed",
    "Sucker Punch",
    "Toxic Spikes",
    "Heart Swap",
    "Aqua Ring",
    "Magnet Rise",
    "Flare Blitz",
    "Force Palm",
    "Aura Sphere",
    "Rock Polish",
    "Poison Jab",
    "Dark Pulse",
    "Night Slash",
    "Aqua Tail",
    "Seed Bomb",
    "Air Slash",
    "X Scissor",
    "Bug Buzz",
    "Dragon Pulse",
    "Dragon Rush",
    "Power Gem",
    "Drain Punch",
    "Vacuum Wave",
    "Focus Blast",
    "Energy Ball",
    "Brave Bird",
    "Earth Power",
    "Switcheroo",
    "Giga Impact",
    "Nasty Plot",
    "Bullet Punch",
    "Avalanche",
    "Ice Shard",
    "Shadow Claw",
    "Thunder Fang",
    "Ice Fang",
    "Fire Fang",
    "Shadow Sneak",
    "Mud Bomb",
    "Psycho Cut",
    "Zen Headbutt",
    "Mirror Shot",
    "Flash Cannon",
    "Rock Climb",
    "Defog",
    "Trick Room",
    "Draco Meteor",
    "Discharge",
    "Lava Plume",
    "Leaf Storm",
    "Power Whip",
    "Rock Wrecker",
    "Cross Poison",
    "Gunk Shot",
    "Iron Head",
    "Magnet Bomb",
    "Stone Edge",
    "Captivate",
    "Stealth Rock",
    "Grass Knot",
    "Chatter",
    "Judgment",
    "Bug Bite",
    "Charge Beam",
    "Wood Hammer",
    "Aqua Jet",
    "Attack Order",
    "Defend Order",
    "Heal Order",
    "Head Smash",
    "Double Hit",
    "Roar Of Time",
    "Spacial Rend",
    "Lunar Dance",
    "Crush Grip",
    "Magma Storm",
    "Dark Void",
    "Seed Flare",
    "Ominous Wind",
    "Shadow Force",
    "Hone Claws",
    "Wide Guard",
    "Guard Split",
    "Power Split",
    "Wonder Room",
    "Psyshock",
    "Venoshock",
    "Autotomize",
    "Rage Powder",
    "Telekinesis",
    "Magic Room",
    "Smack Down",
    "Storm Throw",
    "Flame Burst",
    "Sludge Wave",
    "Quiver Dance",
    "Heavy Slam",
    "Synchronoise",
    "Electro Ball",
    "Soak",
    "Flame Charge",
    "Coil",
    "Low Sweep",
    "Acid Spray",
    "Foul Play",
    "Simple Beam",
    "Entrainment",
    "After You",
    "Round",
    "Echoed Voice",
    "Chip Away",
    "Clear Smog",
    "Stored Power",
    "Quick Guard",
    "Ally Switch",
    "Scald",
    "Shell Smash",
    "Heal Pulse",
    "Hex",
    "Sky Drop",
    "Shift Gear",
    "Circle Throw",
    "Incinerate",
    "Quash",
    "Acrobatics",
    "Reflect Type",
    "Retaliate",
    "Final Gambit",
    "Bestow",
    "Inferno",
    "Water Pledge",
    "Fire Pledge",
    "Grass Pledge",
    "Volt Switch",
    "Struggle Bug",
    "Bulldoze",
    "Frost Breath",
    "Dragon Tail",
    "Work Up",
    "Electroweb",
    "Wild Charge",
    "Drill Run",
    "Dual Chop",
    "Heart Stamp",
    "Horn Leech",
    "Sacred Sword",
    "Razor Shell",
    "Heat Crash",
    "Leaf Tornado",
    "Steamroller",
    "Cotton Guard",
    "Night Daze",
    "Psystrike",
    "Tail Slap",
    "Hurricane",
    "Head Charge",
    "Gear Grind",
    "Searing Shot",
    "Techno Blast",
    "Relic Song",
    "Secret Sword",
    "Glaciate",
    "Bolt Strike",
    "Blue Flare",
    "Fiery Dance",
    "Freeze Shock",
    "Ice Burn",
    "Snarl",
    "Icicle Crash",
    "V Create",
    "Fusion Flare",
    "Fusion Bolt",
    "Flying Press",
    "Mat Block",
    "Belch",
    "Rototiller",
    "Sticky Web",
    "Fell Stinger",
    "Phantom Force",
    "Trick Or Treat",
    "Noble Roar",
    "Ion Deluge",
    "Parabolic Charge",
    "Forests Curse",
    "Petal Blizzard",
    "Freeze Dry",
    "Disarming Voice",
    "Parting Shot",
    "Topsy Turvy",
    "Draining Kiss",
    "Crafty Shield",
    "Flower Shield",
    "Grassy Terrain",
    "Misty Terrain",
    "Electrify",
    "Play Rough",
    "Fairy Wind",
    "Moonblast",
    "Boomburst",
    "Fairy Lock",
    "Kings Shield",
    "Play Nice",
    "Confide",
    "Diamond Storm",
    "Steam Eruption",
    "Hyperspace Hole",
    "Water Shuriken",
    "Mystical Fire",
    "Spiky Shield",
    "Aromatic Mist",
    "Eerie Impulse",
    "Venom Drench",
    "Powder",
    "Geomancy",
    "Magnetic Flux",
    "Happy Hour",
    "Electric Terrain",
    "Dazzling Gleam",
    "Celebrate",
    "Hold Hands",
    "Baby Doll Eyes",
    "Nuzzle",
    "Hold Back",
    "Infestation",
    "Power Up Punch",
    "Oblivion Wing",
    "Thousand Arrows",
    "Thousand Waves",
    "Lands Wrath",
    "Light Of Ruin",
    "Origin Pulse",
    "Precipice Blades",
    "Dragon Ascent",
    "Hyperspace Fury",
    "Breakneck Blitz  Physical",
    "Breakneck Blitz  Special",
    "All Out Pummeling  Physical",
    "All Out Pummeling  Special",
    "Supersonic Skystrike  Physical",
    "Supersonic Skystrike  Special",
    "Acid Downpour  Physical",
    "Acid Downpour  Special",
    "Tectonic Rage  Physical",
    "Tectonic Rage  Special",
    "Continental Crush  Physical",
    "Continental Crush  Special",
    "Savage Spin Out  Physical",
    "Savage Spin Out  Special",
    "Never Ending Nightmare  Physical",
    "Never Ending Nightmare  Special",
    "Corkscrew Crash  Physical",
    "Corkscrew Crash  Special",
    "Inferno Overdrive  Physical",
    "Inferno Overdrive  Special",
    "Hydro Vortex  Physical",
    "Hydro Vortex  Special",
    "Bloom Doom  Physical",
    "Bloom Doom  Special",
    "Gigavolt Havoc  Physical",
    "Gigavolt Havoc  Special",
    "Shattered Psyche  Physical",
    "Shattered Psyche  Special",
    "Subzero Slammer  Physical",
    "Subzero Slammer  Special",
    "Devastating Drake  Physical",
    "Devastating Drake  Special",
    "Black Hole Eclipse  Physical",
    "Black Hole Eclipse  Special",
    "Twinkle Tackle  Physical",
    "Twinkle Tackle  Special",
    "Catastropika",
    "Shore Up",
    "First Impression",
    "Baneful Bunker",
    "Spirit Shackle",
    "Darkest Lariat",
    "Sparkling Aria",
    "Ice Hammer",
    "Floral Healing",
    "High Horsepower",
    "Strength Sap",
    "Solar Blade",
    "Leafage",
    "Spotlight",
    "Toxic Thread",
    "Laser Focus",
    "Gear Up",
    "Throat Chop",
    "Pollen Puff",
    "Anchor Shot",
    "Psychic Terrain",
    "Lunge",
    "Fire Lash",
    "Power Trip",
    "Burn Up",
    "Speed Swap",
    "Smart Strike",
    "Purify",
    "Revelation Dance",
    "Core Enforcer",
    "Trop Kick",
    "Instruct",
    "Beak Blast",
    "Clanging Scales",
    "Dragon Hammer",
    "Brutal Swing",
    "Aurora Veil",
    "Sinister Arrow Raid",
    "Malicious Moonsault",
    "Oceanic Operetta",
    "Guardian Of Alola",
    "Soul Stealing 7 Star Strike",
    "Stoked Sparksurfer",
    "Pulverizing Pancake",
    "Extreme Evoboost",
    "Genesis Supernova",
    "Shell Trap",
    "Fleur Cannon",
    "Psychic Fangs",
    "Stomping Tantrum",
    "Shadow Bone",
    "Accelerock",
    "Liquidation",
    "Prismatic Laser",
    "Spectral Thief",
    "Sunsteel Strike",
    "Moongeist Beam",
    "Tearful Look",
    "Zing Zap",
    "Natures Madness",
    "Multi Attack",
    "10 000 000 Volt Thunderbolt",
    "Mind Blown",
    "Plasma Fists",
    "Photon Geyser",
    "Light That Burns The Sky",
    "Searing Sunraze Smash",
    "Menacing Moonraze Maelstrom",
    "Lets Snuggle Forever",
    "Splintered Stormshards",
    "Clangorous Soulblaze",
    "Zippy Zap",
    "Splishy Splash",
    "Floaty Fall",
    "Pika Papow",
    "Bouncy Bubble",
    "Buzzy Buzz",
    "Sizzly Slide",
    "Glitzy Glow",
    "Baddy Bad",
    "Sappy Seed",
    "Freezy Frost",
    "Sparkly Swirl",
    "Veevee Volley",
    "Double Iron Bash",
    "Max Guard",
    "Dynamax Cannon",
    "Snipe Shot",
    "Jaw Lock",
    "Stuff Cheeks",
    "No Retreat",
    "Tar Shot",
    "Magic Powder",
    "Dragon Darts",
    "Teatime",
    "Octolock",
    "Bolt Beak",
    "Fishious Rend",
    "Court Change",
    "Max Flare",
    "Max Flutterby",
    "Max Lightning",
    "Max Strike",
    "Max Knuckle",
    "Max Phantasm",
    "Max Hailstorm",
    "Max Ooze",
    "Max Geyser",
    "Max Airstream",
    "Max Starfall",
    "Max Wyrmwind",
    "Max Mindstorm",
    "Max Rockfall",
    "Max Quake",
    "Max Darkness",
    "Max Overgrowth",
    "Max Steelspike",
    "Clangorous Soul",
    "Body Press",
    "Decorate",
    "Drum Beating",
    "Snap Trap",
    "Pyro Ball",
    "Behemoth Blade",
    "Behemoth Bash",
    "Aura Wheel",
    "Breaking Swipe",
    "Branch Poke",
    "Overdrive",
    "Apple Acid",
    "Grav Apple",
    "Spirit Break",
    "Strange Steam",
    "Life Dew",
    "Obstruct",
    "False Surrender",
    "Meteor Assault",
    "Eternabeam",
    "Steel Beam",
    "Expanding Force",
    "Steel Roller",
    "Scale Shot",
    "Meteor Beam",
    "Shell Side Arm",
    "Misty Explosion",
    "Grassy Glide",
    "Rising Voltage",
    "Terrain Pulse",
    "Skitter Smack",
    "Burning Jealousy",
    "Lash Out",
    "Poltergeist",
    "Corrosive Gas",
    "Coaching",
    "Flip Turn",
    "Triple Axel",
    "Dual Wingbeat",
    "Scorching Sands",
    "Jungle Healing",
    "Wicked Blow",
    "Surging Strikes",
    "Thunder Cage",
    "Dragon Energy",
    "Freezing Glare",
    "Fiery Wrath",
    "Thunderous Kick",
    "Glacial Lance",
    "Astral Barrage",
    "Eerie Spell",
    "Dire Claw",
    "Psyshield Bash",
    "Power Shift",
    "Stone Axe",
    "Springtide Storm",
    "Mystical Power",
    "Raging Fury",
    "Wave Crash",
    "Chloroblast",
    "Mountain Gale",
    "Victory Dance",
    "Headlong Rush",
    "Barb Barrage",
    "Esper Wing",
    "Bitter Malice",
    "Shelter",
    "Triple Arrows",
    "Infernal Parade",
    "Ceaseless Edge",
    "Bleakwind Storm",
    "Wildbolt Storm",
    "Sandsear Storm",
    "Lunar Blessing",
    "Take Heart",
    "Tera Blast",
    "Silk Trap",
    "Axe Kick",
    "Last Respects",
    "Lumina Crash",
    "Order Up",
    "Jet Punch",
    "Spicy Extract",
    "Spin Out",
    "Population Bomb",
    "Ice Spinner",
    "Glaive Rush",
    "Revival Blessing",
    "Salt Cure",
    "Triple Dive",
    "Mortal Spin",
    "Doodle",
    "Fillet Away",
    "Kowtow Cleave",
    "Flower Trick",
    "Torch Song",
    "Aqua Step",
    "Raging Bull",
    "Make It Rain",
    "Psyblade",
    "Hydro Steam",
    "Ruination",
    "Collision Course",
    "Electro Drift",
    "Shed Tail",
    "Chilly Reception",
    "Tidy Up",
    "Snowscape",
    "Pounce",
    "Trailblaze",
    "Chilling Water",
    "Hyper Drill",
    "Twin Beam",
    "Rage Fist",
    "Armor Cannon",
    "Bitter Blade",
    "Double Shock",
    "Gigaton Hammer",
    "Comeuppance",
    "Aqua Cutter",
    "Blazing Torque",
    "Wicked Torque",
    "Noxious Torque",
    "Combat Torque",
    "Magical Torque",
    "Blood Moon",
    "Matcha Gotcha",
    "Syrup Bomb",
    "Ivy Cudgel",
    "Electro Shot",
    "Tera Starstorm",
    "Fickle Beam",
    "Burning Bulwark",
    "Thunderclap",
    "Mighty Cleave",
    "Tachyon Cutter",
    "Hard Press",
    "Dragon Cheer",
    "Alluring Voice",
    "Temper Flare",
    "Supercell Slam",
    "Psychic Noise",
    "Upper Hand",
    "Malignant Chain",
    "Shadow Rush",
    "Shadow Blast",
    "Shadow Blitz",
    "Shadow Bolt",
    "Shadow Break",
    "Shadow Chill",
    "Shadow End",
    "Shadow Fire",
    "Shadow Rave",
    "Shadow Storm",
    "Shadow Wave",
    "Shadow Down",
    "Shadow Half",
    "Shadow Hold",
    "Shadow Mist",
    "Shadow Panic",
    "Shadow Shed",
    "Shadow Sky",
)

POKEMON_REGIONS: tuple[str, ...] = (
    "Kanto",
    "Johto",
    "Hoenn",
    "Sinnoh",
    "Unova",
    "Kalos",
    "Alola",
    "Galar",
    "Hisui",
    "Paldea",
)

POKEMON_LOCATIONS: tuple[str, ...] = (
    "Canalave City",
    "Eterna City",
    "Pastoria City",
    "Sunyshore City",
    "Sinnoh Pokemon League",
    "Oreburgh Mine",
    "Valley Windworks",
    "Eterna Forest",
    "Fuego Ironworks",
    "Mt Coronet",
    "Great Marsh",
    "Solaceon Ruins",
    "Sinnoh Victory Road",
    "Ravaged Path",
    "Oreburgh Gate",
    "Stark Mountain",
    "Spring Path",
    "Turnback Cave",
    "Snowpoint Temple",
    "Wayward Cave",
    "Ruin Maniac Cave",
    "Trophy Garden",
    "Iron Island",
    "Old Chateau",
    "Lake Verity",
    "Lake Valor",
    "Lake Acuity",
    "Valor Lakefront",
    "Acuity Lakefront",
    "Sinnoh Route 201",
    "Sinnoh Route 202",
    "Sinnoh Route 203",
    "Sinnoh Route 204",
    "Sinnoh Route 205",
    "Sinnoh Route 206",
    "Sinnoh Route 207",
    "Sinnoh Route 208",
    "Sinnoh Route 209",
    "Lost Tower",
    "Sinnoh Route 210",
    "Sinnoh Route 211",
    "Sinnoh Route 212",
    "Sinnoh Route 213",
    "Sinnoh Route 214",
    "Sinnoh Route 215",
    "Sinnoh Route 216",
    "Sinnoh Route 217",
    "Sinnoh Route 218",
    "Sinnoh Route 219",
    "Sinnoh Route 221",
    "Sinnoh Route 222",
    "Sinnoh Route 224",
    "Sinnoh Route 225",
    "Sinnoh Route 227",
    "Sinnoh Route 228",
    "Sinnoh Route 229",
    "Twinleaf Town",
    "Celestic Town",
    "Resort Area",
    "Sinnoh Sea Route 220",
    "Sinnoh Sea Route 223",
    "Sinnoh Sea Route 226",
    "Sinnoh Sea Route 230",
    "Blackthorn City",
    "Burned Tower",
    "Celadon City",
    "Cerulean City",
    "Cherrygrove City",
    "Cianwood City",
    "Cinnabar Island",
    "Dark Cave",
    "Digletts Cave",
    "Dragons Den",
    "Ecruteak City",
    "Fuchsia City",
    "Ice Path",
    "Ilex Forest",
    "Lake Of Rage",
    "Mt Moon",
    "Mt Mortar",
    "Mt Silver",
    "National Park",
    "New Bark Town",
    "Olivine City",
    "Pallet Town",
    "Rock Tunnel",
    "Kanto Route 1",
    "Kanto Route 10",
    "Kanto Route 11",
    "Kanto Route 12",
    "Kanto Route 13",
    "Kanto Route 14",
    "Kanto Route 15",
    "Kanto Route 16",
    "Kanto Route 17",
    "Kanto Route 18",
    "Kanto Sea Route 19",
    "Kanto Route 2",
    "Kanto Sea Route 20",
    "Kanto Sea Route 21",
    "Kanto Route 22",
    "Kanto Route 24",
    "Kanto Route 25",
    "Kanto Route 26",
    "Kanto Route 27",
    "Kanto Route 28",
    "Johto Route 29",
    "Kanto Route 3",
    "Johto Route 30",
    "Johto Route 31",
    "Johto Route 32",
    "Johto Route 33",
    "Johto Route 34",
    "Johto Route 35",
    "Johto Route 36",
    "Johto Route 37",
    "Johto Route 38",
    "Johto Route 39",
    "Kanto Route 4",
    "Johto Sea Route 40",
    "Johto Sea Route 41",
    "Johto Route 42",
    "Johto Route 43",
    "Johto Route 44",
    "Johto Route 45",
    "Johto Route 46",
    "Johto Route 47",
    "Johto Route 48",
    "Kanto Route 5",
    "Kanto Route 6",
    "Kanto Route 7",
    "Kanto Route 8",
    "Kanto Route 9",
    "Ruins Of Alph",
    "Seafoam Islands",
    "Slowpoke Well",
    "Sprout Tower",
    "Bell Tower",
    "Tohjo Falls",
    "Union Cave",
    "Cerulean Cave",
    "Unknown All Poliwag",
    "Unknown All Rattata",
    "Unknown All Bugs",
    "Vermilion City",
    "Kanto Victory Road 1",
    "Violet City",
    "Viridian City",
    "Viridian Forest",
    "Whirl Islands",
    "Kanto Route 23",
    "Power Plant",
    "Kanto Victory Road 2",
    "Pokemon Tower",
    "Pokemon Mansion",
    "Kanto Safari Zone",
    "Sandgem Town",
    "Floaroma Town",
    "Solaceon Town",
    "Jubilife City",
    "Oreburgh City",
    "Hearthome City",
    "Veilstone City",
    "Snowpoint City",
    "Spear Pillar",
    "Pal Park",
    "Amity Square",
    "Floaroma Meadow",
    "Fullmoon Island",
    "Sendoff Spring",
    "Flower Paradise",
    "Maniac Tunnel",
    "Galactic Hq",
    "Verity Lakefront",
    "Newmoon Island",
    "Sinnoh Battle Tower",
    "Fight Area",
    "Survival Area",
    "Seabreak Path",
    "Sinnoh Hall Of Origin 1",
    "Sinnoh Hall Of Origin 2",
    "Verity Cavern",
    "Valor Cavern",
    "Acuity Cavern",
    "Jubilife Tv",
    "Poketch Co",
    "Gts",
    "Trainers School",
    "Mining Museum",
    "Sinnoh Flower Shop",
    "Sinnoh Cycle Shop",
    "Contest Hall",
    "Poffin House",
    "Sinnoh Foreign Building",
    "Pokemon Day Care",
    "Veilstone Store",
    "Sinnoh Game Corner",
    "Canalave Library",
    "Vista Lighthouse",
    "Sunyshore Market",
    "Footstep House",
    "Sinnoh Cafe",
    "Grand Lake",
    "Sinnoh Restaurant",
    "Battle Park",
    "Battle Frontier",
    "Battle Factory",
    "Battle Castle",
    "Battle Arcade",
    "Battle Hall",
    "Distortion World",
    "Sinnoh Global Terminal",
    "Sinnoh Villa",
    "Battleground",
    "Rotoms Room",
    "Tg Eterna Bldg",
    "Iron Ruins",
    "Iceberg Ruins",
    "Rock Peak Ruins",
    "Azalea Town",
    "Goldenrod City",
    "Mahogany Town",
    "Pewter City",
    "Lavender Town",
    "Indigo Plateau",
    "Saffron City",
    "Johto Lighthouse",
    "Team Rocket Hq",
    "Goldenrod Tunnel",
    "Mt Silver Cave",
    "Pokeathlon Dome",
    "Ss Aqua",
    "Safari Zone Gate",
    "Cliff Cave",
    "Frontier Access",
    "Bellchime Trail",
    "Sinjoh Ruins",
    "Embedded Tower",
    "Pokewalker",
    "Cliff Edge Gate",
    "Radio Tower",
    "Day Care Couple",
    "Link Trade Arrive",
    "Link Trade Met",
    "Kanto",
    "Johto",
    "Hoenn",
    "Sinnoh",
    "Distant Land",
    "Traveling Man",
    "Riley",
    "Cynthia",
    "Mystery Zone",
    "Lovely Place",
    "Pokemon Ranger",
    "Faraway Place",
    "Pokemon Movie",
    "Pokemon Movie 06",
    "Pokemon Movie 07",
    "Pokemon Movie 08",
    "Pokemon Movie 09",
    "Pokemon Movie 10",
    "Pokemon Movie 11",
    "Pokemon Movie 12",
    "Pokemon Movie 13",
    "Pokemon Movie 14",
    "Pokemon Movie 15",
    "Pokemon Movie 16",
    "Pokemon Cartoon",
    "Space World",
    "Space World 06",
    "Space World 07",
    "Space World 08",
    "Space World 09",
    "Space World 10",
    "Space World 11",
    "Space World 12",
    "Space World 13",
    "Space World 14",
    "Space World 15",
    "Space World 16",
    "Pokemon Festa",
    "Pokemon Festa 06",
    "Pokemon Festa 07",
    "Pokemon Festa 08",
    "Pokemon Festa 09",
    "Pokemon Festa 10",
    "Pokemon Festa 11",
    "Pokemon Festa 12",
    "Pokemon Festa 13",
    "Pokemon Festa 14",
    "Pokemon Festa 15",
    "Pokemon Festa 16",
    "Pokepark",
    "Pokepark 06",
    "Pokepark 07",
    "Pokepark 08",
    "Pokepark 09",
    "Pokepark 10",
    "Pokepark 11",
    "Pokepark 12",
    "Pokepark 13",
    "Pokepark 14",
    "Pokepark 15",
    "Pokepark 16",
    "Pokemon Center",
    "Pc Tokyo",
    "Pc Osaka",
    "Pc Fukuoka",
    "Pc Nagoya",
    "Pc Sapporo",
    "Pc Yokohama",
    "Nintendo World",
    "Pokemon Event",
    "Pokemon Event 06",
    "Pokemon Event 07",
    "Pokemon Event 08",
    "Pokemon Event 09",
    "Pokemon Event 10",
    "Pokemon Event 11",
    "Pokemon Event 12",
    "Pokemon Event 13",
    "Pokemon Event 14",
    "Pokemon Event 15",
    "Pokemon Event 16",
    "Wi Fi Event",
    "Wi Fi Gift",
    "Pokemon Fan Club",
    "Event Site",
    "Concert Event",
    "Mr Pokemon",
    "Primo",
    "Unova Mystery Zone",
    "Unova Faraway Place",
    "Nuvema Town",
    "Accumula Town",
    "Striaton City",
    "Nacrene City",
    "Castelia City",
    "Nimbasa City",
    "Driftveil City",
    "Mistralton City",
    "Icirrus City",
    "Opelucid City",
    "Unova Route 1",
    "Unova Route 2",
    "Unova Route 3",
    "Unova Route 4",
    "Unova Route 5",
    "Unova Route 6",
    "Unova Route 7",
    "Unova Route 8",
    "Unova Route 9",
    "Unova Route 10",
    "Unova Route 11",
    "Unova Route 12",
    "Unova Route 13",
    "Unova Route 14",
    "Unova Route 15",
    "Unova Route 16",
    "Unova Route 17",
    "Unova Route 18",
    "Dreamyard",
    "Pinwheel Forest",
    "Desert Resort",
    "Relic Castle",
    "Cold Storage",
    "Chargestone Cave",
    "Twist Mountain",
    "Dragonspiral Tower",
    "Unova Victory Road",
    "Lacunosa Town",
    "Undella Town",
    "Anville Town",
    "Unova Pokemon League",
    "Ns Castle",
    "Royal Unova",
    "Gear Station",
    "Battle Subway",
    "Musical Theater",
    "Black City",
    "White Forest",
    "Unity Tower",
    "Wellspring Cave",
    "Mistralton Cave",
    "Rumination Field",
    "Celestial Tower",
    "Moor Of Icirrus",
    "Unova Shopping Mall",
    "Challengers Cave",
    "Poke Transfer Lab",
    "Giant Chasm",
    "Liberty Garden",
    "P2 Laboratory",
    "Skyarrow Bridge",
    "Driftveil Drawbridge",
    "Tubeline Bridge",
    "Village Bridge",
    "Marvelous Bridge",
    "Entralink",
    "Abundant Shrine",
    "Undella Bay",
    "Lostlorn Forest",
    "Trial Chamber",
    "Guidance Chamber",
    "Entree Forest",
    "Accumula Gate",
    "Undella Gate",
    "Nacrene Gate",
    "Castelia Gate",
    "Nimbasa Gate",
    "Opelucid Gate",
    "Black Gate",
    "White Gate",
    "Bridge Gate",
    "Route Gate",
    "Abyssal Ruins",
    "Petalburg City",
    "Slateport City",
    "Lilycove City",
    "Mossdeep City",
    "Sootopolis City",
    "Ever Grande City",
    "Meteor Falls",
    "Rusturf Tunnel",
    "Granite Cave",
    "Petalburg Woods",
    "Jagged Pass",
    "Fiery Path",
    "Mt Pyre",
    "Seafloor Cavern",
    "Cave Of Origin",
    "Hoenn Victory Road",
    "Shoal Cave",
    "New Mauville",
    "Abandoned Ship",
    "Sky Pillar",
    "Hoenn Route 101",
    "Hoenn Route 102",
    "Hoenn Route 103",
    "Hoenn Route 104",
    "Hoenn Route 105",
    "Hoenn Route 106",
    "Hoenn Route 107",
    "Hoenn Route 108",
    "Hoenn Route 109",
    "Hoenn Route 110",
    "Hoenn Route 111",
    "Hoenn Route 112",
    "Hoenn Route 113",
    "Hoenn Route 114",
    "Hoenn Route 115",
    "Hoenn Route 116",
    "Hoenn Route 117",
    "Hoenn Route 118",
    "Hoenn Route 119",
    "Hoenn Route 120",
    "Hoenn Route 121",
    "Hoenn Route 122",
    "Hoenn Route 123",
    "Hoenn Route 124",
    "Hoenn Route 125",
    "Hoenn Route 126",
    "Hoenn Route 127",
    "Hoenn Route 128",
    "Hoenn Route 129",
    "Hoenn Route 130",
    "Hoenn Route 131",
    "Hoenn Route 132",
    "Hoenn Route 133",
    "Hoenn Route 134",
    "Hoenn Safari Zone",
    "Dewford Town",
    "Pacifidlog Town",
    "Magma Hideout",
    "Mirage Tower",
    "Desert Underpass",
    "Artisan Cave",
    "Hoenn Altering Cave",
    "Monean Chamber",
    "Liptoo Chamber",
    "Weepth Chamber",
    "Dilford Chamber",
    "Scufib Chamber",
    "Rixy Chamber",
    "Viapos Chamber",
    "Ss Anne",
    "Mt Ember",
    "Berry Forest",
    "Icefall Cave",
    "Pattern Bush",
    "Lost Cave",
    "Kindle Road",
    "Treasure Beach",
    "Cape Brink",
    "Bond Bridge",
    "Three Isle Port",
    "Resort Gorgeous",
    "Water Labyrinth",
    "Five Isle Meadow",
    "Memorial Pillar",
    "Outcast Island",
    "Green Path",
    "Water Path",
    "Ruin Valley",
    "Trainer Tower",
    "Canyon Entrance",
    "Sevault Canyon",
    "Tanoby Ruins",
    "One Island",
    "Four Island",
    "Five Island",
    "Kanto Altering Cave",
    "Aspertia City",
    "Virbank City",
    "Humilau City",
    "Pokestar Studios",
    "Join Avenue",
    "Floccesy Town",
    "Lentimas Town",
    "Unova Route 19",
    "Unova Route 20",
    "Unova Route 21",
    "Unova Route 22",
    "Unova Route 23",
    "Castelia Sewers",
    "Floccesy Ranch",
    "Virbank Complex",
    "Reversal Mountain",
    "Strange House",
    "Unova Victory Road 2",
    "Plasma Frigate",
    "Relic Passage",
    "Clay Tunnel",
    "White Treehollow",
    "Black Tower",
    "Seaside Cave",
    "Cave Of Being",
    "Hidden Grotto",
    "Marine Tube",
    "Virbank Gate",
    "Aspertia Gate",
    "Nature Sanctuary",
    "Medal Secretariat",
    "Underground Ruins",
    "Rocky Mountain Room",
    "Glacier Room",
    "Iron Room",
    "Pledge Grove",
    "Littleroot Town",
    "Oldale Town",
    "Lavaridge Town",
    "Fallarbor Town",
    "Verdanturf Town",
    "Mauville City",
    "Rustboro City",
    "Fortree City",
    "Underwater",
    "Mt Chimney",
    "Mirage Island",
    "Southern Island",
    "Sealed Chamber",
    "Scorched Slab",
    "Island Cave",
    "Desert Ruins",
    "Ancient Tomb",
    "Inside Of Truck",
    "Secret Base",
    "Hoenn Battle Tower",
    "Vaniville Town",
    "Kalos Route 1",
    "Vaniville Pathway",
    "Aquacorde Town",
    "Kalos Route 2",
    "Avance Trail",
    "Santalune Forest",
    "Kalos Route 3",
    "Ouvert Way",
    "Santalune City",
    "Kalos Route 4",
    "Parterre Way",
    "Lumiose City",
    "Prism Tower",
    "Lysandre Labs",
    "Kalos Route 5",
    "Versant Road",
    "Camphrier Town",
    "Shabboneau Castle",
    "Kalos Route 6",
    "Palais Lane",
    "Parfum Palace",
    "Kalos Route 7",
    "Rivière Walk",
    "Cyllage City",
    "Kalos Route 8",
    "Muraille Coast",
    "Ambrette Town",
    "Kalos Route 9",
    "Spikes Passage",
    "Battle Chateau",
    "Kalos Route 10",
    "Menhir Trail",
    "Geosenge Town",
    "Kalos Route 11",
    "Miroir Way",
    "Reflection Cave",
    "Shalour City",
    "Tower Of Mastery",
    "Kalos Route 12",
    "Fourrage Road",
    "Coumarine City",
    "Kalos Route 13",
    "Lumiose Badlands",
    "Kalos Route 14",
    "Laverre Nature Trail",
    "Laverre City",
    "Poke Ball Factory",
    "Kalos Route 15",
    "Brun Way",
    "Dendemille Town",
    "Kalos Route 16",
    "Melancolie Path",
    "Frost Cavern",
    "Kalos Route 17",
    "Mamoswine Road",
    "Anistar City",
    "Kalos Route 18",
    "Vallee Etroite Way",
    "Couriway Town",
    "Kalos Route 19",
    "Grande Vallee Way",
    "Snowbelle City",
    "Kalos Route 20",
    "Winding Woods",
    "Pokemon Village",
    "Kalos Route 21",
    "Dernière Way",
    "Kalos Route 22",
    "Detourner Way",
    "Kalos Victory Road",
    "Kalos Pokemon League",
    "Kiloude City",
    "Battle Maison",
    "Azure Bay",
    "Dendemille Gate",
    "Couriway Gate",
    "Ambrette Gate",
    "Lumiose Gate",
    "Shalour Gate",
    "Coumarine Gate",
    "Laverre Gate",
    "Anistar Gate",
    "Snowbelle Gate",
    "Glittering Cave",
    "Connecting Cave",
    "Zubat Roost",
    "Kalos Power Plant",
    "Team Flare Secret Hq",
    "Terminus Cave",
    "Lost Hotel",
    "Chamber Of Emptiness",
    "Sea Spirits Den",
    "Friend Safari",
    "Blazing Chamber",
    "Flood Chamber",
    "Ironworks Chamber",
    "Dragonmark Chamber",
    "Radiant Chamber",
    "Pokemon League Gate",
    "Lumiose Station",
    "Kiloude Station",
    "Ambrette Aquarium",
    "Unknown Dungeon",
    "Hoenn Pokemon League",
    "Team Aqua Hideout",
    "Sea Mauville",
    "Team Magma Hideout",
    "Battle Resort",
    "Ss Tidal",
    "Mirage Forest",
    "Mirage Cave",
    "Mirage Mountain",
    "Trackless Forest",
    "Pathless Plain",
    "Nameless Cavern",
    "Fabled Cave",
    "Gnarled Den",
    "Crescent Isle",
    "Secret Islet",
    "Soaring In The Sky",
    "Secret Shore",
    "Secret Meadow",
    "Alola Route 1  Hauoli Outskirts",
    "Alola Route 1",
    "Alola Route 3",
    "Alola Route 2",
    "Kalae Bay",
    "Melemele Sea",
    "Hauoli City  Beachfront",
    "Hauoli City  Shopping District",
    "Hauoli City  Marina",
    "Iki Town",
    "Mahalo Trail",
    "Mahalo Trail  Plank Bridge",
    "Ruins Of Conflict",
    "Ten Carat Hill",
    "Ten Carat Hill  Farthest Hollow",
    "Hauoli Cemetery",
    "Melemele Meadow",
    "Seaward Cave",
    "Berry Fields",
    "Verdant Cavern  Trial Site",
    "Verdant Cavern  Totems Den",
    "Alola Route 4",
    "Alola Route 5",
    "Alola Route 6",
    "Alola Route 7",
    "Alola Route 8",
    "Alola Route 9",
    "Hano Grand Resort",
    "Hano Beach",
    "Akala Meadow",
    "Paniola Town",
    "Heahea City",
    "Konikoni City",
    "Royal Avenue",
    "Memorial Hill",
    "Paniola Ranch",
    "Wela Volcano Park",
    "Wela Volcano Park  Totems Den",
    "Brooklet Hill",
    "Brooklet Hill  Totems Den",
    "Lush Jungle",
    "Ruins Of Life",
    "Akala Outskirts",
    "Digletts Tunnel",
    "Battle Royal Dome",
    "Alola Route 10",
    "Alola Route 11",
    "Secluded Shore",
    "Alola Route 13",
    "Tapu Village",
    "Alola Route 15",
    "Alola Route 16",
    "Alola Route 17",
    "Alola Route 12",
    "Haina Desert",
    "Alola Route 14",
    "Ulaula Meadow",
    "Po Town",
    "Malie City Proper",
    "Malie Garden",
    "Mount Hokulani",
    "Blush Mountain",
    "Ruins Of Abundance",
    "Lake Of The Sunne",
    "Lake Of The Moone",
    "Mount Lanakila",
    "Shady House",
    "Thrifty Megamart  Abandoned Site",
    "Hokulani Observatory",
    "Alola Pokemon League",
    "Poni Meadow",
    "Poni Wilds",
    "Ancient Poni Path",
    "Poni Breaker Coast",
    "Poni Grove",
    "Poni Plains",
    "Poni Coast",
    "Poni Gauntlet",
    "Seafolk Village",
    "Vast Poni Canyon",
    "Altar Of The Sunne",
    "Altar Of The Moone",
    "Ruins Of Hope",
    "Resolution Cave",
    "Exeggutor Island",
    "Battle Tree",
    "Aether Paradise",
    "Ultra Space",
    "Malie City  Outer Cape",
    "Roaming Kanto",
    "Roaming Johto",
    "Roaming Hoenn",
    "Roaming Sinnoh",
    "Terra Cave",
    "Marine Cave",
    "Two Island",
    "Three Island",
    "Three Isle Path",
    "Six Island",
    "Seven Island",
    "Birth Island",
    "Navel Rock",
    "Faraway Island",
    "Hoenn Battle Frontier",
    "Johto Safari Zone",
    "Cabo Poco",
    "Los Platos",
    "Mesagoza",
    "Cortondo",
    "Alfornada",
    "Pokemon League",
    "Artazon",
    "Levincia",
    "Zapapico",
    "Cascarrafa",
    "Porto Marinada",
    "Medali",
    "Montenevera",
    "Paldea South Province Area One",
    "Paldea South Province Area Two",
    "Paldea South Province Area Three",
    "Paldea South Province Area Four",
    "Paldea South Province Area Five",
    "Paldea South Province Area Six",
    "South Paldean Sea",
    "Poco Path",
    "Inlet Grotto",
    "Naranja Academy",
    "Alfornada Cavern",
    "Grasswither Shrine",
    "Paldea East Province Area One",
    "Paldea East Province Area Two",
    "Paldea East Province Area Three",
    "East Paldean Sea",
    "Tagtree Thicket",
    "Schedar Squads Base",
    "Navi Squads Base",
    "Paldea West Province Area One",
    "Paldea West Province Area Two",
    "Paldea West Province Area Three",
    "Asado Desert",
    "West Paldean Sea",
    "Segin Squads Base",
    "Icerend Shrine",
    "Paldea North Province Area One",
    "Paldea North Province Area Two",
    "Paldea North Province Area Three",
    "Casseroya Lake",
    "Dalizapa Passage",
    "Glaseado Mountain",
    "Socarrat Trail",
    "Groundblight Shrine",
    "Firescourge Shrine",
    "North Paldean Sea",
    "Ruchbah Squads Base",
    "Caph Squads Base",
    "Area Zero",
    "Zero Lab",
    "Galar Route 1",
    "Galar Route 2",
    "Galar Route 3",
    "Galar Route 4",
    "Galar Route 5",
    "Galar Route 6",
    "Galar Route 7",
    "Galar Route 8",
    "Galar Route 9",
    "Galar Route 10",
    "Axews Eye",
    "Ballimere Lake",
    "Ballonlea",
    "Battle Tower",
    "Brawlers Cave",
    "Bridge Field",
    "Challenge Beach",
    "Challenge Road",
    "Circhester",
    "Courageous Cavern",
    "Crown Shrine",
    "Dappled Grove",
    "Dusty Bowl",
    "Dyna Tree Hill",
    "East Lake Axewell",
    "Fields Of Honor",
    "Forest Of Focus",
    "Freezington",
    "Frigid Sea",
    "Frostpoint Field",
    "Galar Mine",
    "Galar Mine No 2",
    "Giants Bed",
    "Giants Foot",
    "Giants Mirror",
    "Giants Seat",
    "Glimwood Tangle",
    "Hammerlocke",
    "Hammerlocke Hills",
    "Honeycalm Island",
    "Honeycalm Sea",
    "Hulbury",
    "Galar Iceberg Ruins",
    "Insular Sea",
    "Galar Iron Ruins",
    "Lake Of Outrage",
    "Lakeside Cave",
    "Loop Lagoon",
    "Master Dojo",
    "Max Lair",
    "Motostoke",
    "Motostoke Outskirts",
    "Motostoke Riverbank",
    "North Lake Miloch",
    "Old Cemetery",
    "Path To The Peak",
    "Postwick",
    "Potbottom Desert",
    "Roaring Sea Caves",
    "Galar Rock Peak Ruins",
    "Rolling Fields",
    "Slippery Slope",
    "Slumbering Weald",
    "Snowslide Slope",
    "Soothing Wetlands",
    "South Lake Miloch",
    "Spikemuth",
    "Split Decision Ruins",
    "Steamdrift Way",
    "Stepping Stone Sea",
    "Stony Wilderness",
    "Stow On Side",
    "Three Point Pass",
    "Tower Of Darkness",
    "Tower Of Waters",
    "Training Lowlands",
    "Tunnel To The Top",
    "Turffield",
    "Warm Up Tunnel",
    "Watchtower Ruins",
    "Wedgehurst",
    "West Lake Axewell",
    "Workout Sea",
    "Wyndon",
    "Aipom Hill",
    "Ancient Quarry",
    "Arenas Approach",
    "Aspiration Hill",
    "Avalanche Slopes",
    "Avaluggs Legacy",
    "Bathers Lagoon",
    "Bolderoll Ravine",
    "Bolderoll Slope",
    "Bonechill Wastes",
    "Brava Arena",
    "Castaway Shore",
    "Celestica Ruins",
    "Celestica Trail",
    "Clamberclaw Cliffs",
    "Cloudcap Pass",
    "Cloudpool Ridge",
    "Coastlands Camp",
    "Cottonsedge Prairie",
    "Crossing Slope",
    "Deadwood Haunt",
    "Deertrack Heights",
    "Deertrack Path",
    "Diamond Heath",
    "Diamond Settlement",
    "Droning Meadow",
    "Fabled Spring",
    "Firespit Island",
    "Floaro Gardens",
    "Gapejaw Bog",
    "Ginkgo Landing",
    "Glacier Terrace",
    "Golden Lowlands",
    "Grandtree Arena",
    "Grueling Grove",
    "Hearts Crag",
    "Heavenward Lookout",
    "Heights Camp",
    "Hideaway Bay",
    "Holm Of Trials",
    "Horseshoe Plains",
    "Ice Column Chamber",
    "Icebound Falls",
    "Icepeak Arena",
    "Icepeak Cavern",
    "Islespy Shore",
    "Jubilife Village",
    "Hisui Lake Acuity",
    "Hisui Lake Valor",
    "Hisui Lake Verity",
    "Lonely Spring",
    "Lunkers Lair",
    "Molten Arena",
    "Moonview Arena",
    "Natures Pantry",
    "Obsidian Falls",
    "Oreburrow Tunnel",
    "Pearl Settlement",
    "Primeval Grotto",
    "Ramanas Island",
    "Sacred Plaza",
    "Sands Reach",
    "Sandgem Flats",
    "Scarlet Bog",
    "Seagrass Haven",
    "Seaside Hollow",
)

POKEMON_ITEMS: tuple[str, ...] = (
    "Master Ball",
    "Ultra Ball",
    "Great Ball",
    "Poke Ball",
    "Safari Ball",
    "Net Ball",
    "Dive Ball",
    "Nest Ball",
    "Repeat Ball",
    "Timer Ball",
    "Luxury Ball",
    "Premier Ball",
    "Dusk Ball",
    "Heal Ball",
    "Quick Ball",
    "Cherish Ball",
    "Potion",
    "Antidote",
    "Burn Heal",
    "Ice Heal",
    "Awakening",
    "Paralyze Heal",
    "Full Restore",
    "Max Potion",
    "Hyper Potion",
    "Super Potion",
    "Full Heal",
    "Revive",
    "Max Revive",
    "Fresh Water",
    "Soda Pop",
    "Lemonade",
    "Moomoo Milk",
    "Energy Powder",
    "Energy Root",
    "Heal Powder",
    "Revival Herb",
    "Ether",
    "Max Ether",
    "Elixir",
    "Max Elixir",
    "Lava Cookie",
    "Berry Juice",
    "Sacred Ash",
    "Hp Up",
    "Protein",
    "Iron",
    "Carbos",
    "Calcium",
    "Rare Candy",
    "Pp Up",
    "Zinc",
    "Pp Max",
    "Old Gateau",
    "Guard Spec",
    "Dire Hit",
    "X Attack",
    "X Defense",
    "X Speed",
    "X Accuracy",
    "X Sp Atk",
    "X Sp Def",
    "Poke Doll",
    "Fluffy Tail",
    "Blue Flute",
    "Yellow Flute",
    "Red Flute",
    "Black Flute",
    "White Flute",
    "Shoal Salt",
    "Shoal Shell",
    "Red Shard",
    "Blue Shard",
    "Yellow Shard",
    "Green Shard",
    "Super Repel",
    "Max Repel",
    "Escape Rope",
    "Repel",
    "Sun Stone",
    "Moon Stone",
    "Fire Stone",
    "Thunder Stone",
    "Water Stone",
    "Leaf Stone",
    "Tiny Mushroom",
    "Big Mushroom",
    "Pearl",
    "Big Pearl",
    "Stardust",
    "Star Piece",
    "Nugget",
    "Heart Scale",
    "Honey",
    "Growth Mulch",
    "Damp Mulch",
    "Stable Mulch",
    "Gooey Mulch",
    "Root Fossil",
    "Claw Fossil",
    "Helix Fossil",
    "Dome Fossil",
    "Old Amber",
    "Armor Fossil",
    "Skull Fossil",
    "Rare Bone",
    "Shiny Stone",
    "Dusk Stone",
    "Dawn Stone",
    "Oval Stone",
    "Odd Keystone",
    "Adamant Orb",
    "Lustrous Orb",
    "Grass Mail",
    "Flame Mail",
    "Bubble Mail",
    "Bloom Mail",
    "Tunnel Mail",
    "Steel Mail",
    "Heart Mail",
    "Snow Mail",
    "Space Mail",
    "Air Mail",
    "Mosaic Mail",
    "Brick Mail",
    "Cheri Berry",
    "Chesto Berry",
    "Pecha Berry",
    "Rawst Berry",
    "Aspear Berry",
    "Leppa Berry",
    "Oran Berry",
    "Persim Berry",
    "Lum Berry",
    "Sitrus Berry",
    "Figy Berry",
    "Wiki Berry",
    "Mago Berry",
    "Aguav Berry",
    "Iapapa Berry",
    "Razz Berry",
    "Bluk Berry",
    "Nanab Berry",
    "Wepear Berry",
    "Pinap Berry",
    "Pomeg Berry",
    "Kelpsy Berry",
    "Qualot Berry",
    "Hondew Berry",
    "Grepa Berry",
    "Tamato Berry",
    "Cornn Berry",
    "Magost Berry",
    "Rabuta Berry",
    "Nomel Berry",
    "Spelon Berry",
    "Pamtre Berry",
    "Watmel Berry",
    "Durin Berry",
    "Belue Berry",
    "Occa Berry",
    "Passho Berry",
    "Wacan Berry",
    "Rindo Berry",
    "Yache Berry",
    "Chople Berry",
    "Kebia Berry",
    "Shuca Berry",
    "Coba Berry",
    "Payapa Berry",
    "Tanga Berry",
    "Charti Berry",
    "Kasib Berry",
    "Haban Berry",
    "Colbur Berry",
    "Babiri Berry",
    "Chilan Berry",
    "Liechi Berry",
    "Ganlon Berry",
    "Salac Berry",
    "Petaya Berry",
    "Apicot Berry",
    "Lansat Berry",
    "Starf Berry",
    "Enigma Berry",
    "Micle Berry",
    "Custap Berry",
    "Jaboca Berry",
    "Rowap Berry",
    "Bright Powder",
    "White Herb",
    "Macho Brace",
    "Exp Share",
    "Quick Claw",
    "Soothe Bell",
    "Mental Herb",
    "Choice Band",
    "Kings Rock",
    "Silver Powder",
    "Amulet Coin",
    "Cleanse Tag",
    "Soul Dew",
    "Deep Sea Tooth",
    "Deep Sea Scale",
    "Smoke Ball",
    "Everstone",
    "Focus Band",
    "Lucky Egg",
    "Scope Lens",
    "Metal Coat",
    "Leftovers",
    "Dragon Scale",
    "Light Ball",
    "Soft Sand",
    "Hard Stone",
    "Miracle Seed",
    "Black Glasses",
    "Black Belt",
    "Magnet",
    "Mystic Water",
    "Sharp Beak",
    "Poison Barb",
    "Never Melt Ice",
    "Spell Tag",
    "Twisted Spoon",
    "Charcoal",
    "Dragon Fang",
    "Silk Scarf",
    "Up Grade",
    "Shell Bell",
    "Sea Incense",
    "Lax Incense",
    "Lucky Punch",
    "Metal Powder",
    "Thick Club",
    "Stick",
    "Red Scarf",
    "Blue Scarf",
    "Pink Scarf",
    "Green Scarf",
    "Yellow Scarf",
    "Wide Lens",
    "Muscle Band",
    "Wise Glasses",
    "Expert Belt",
    "Light Clay",
    "Life Orb",
    "Power Herb",
    "Toxic Orb",
    "Flame Orb",
    "Quick Powder",
    "Focus Sash",
    "Zoom Lens",
    "Metronome",
    "Iron Ball",
    "Lagging Tail",
    "Destiny Knot",
    "Black Sludge",
    "Icy Rock",
    "Smooth Rock",
    "Heat Rock",
    "Damp Rock",
    "Grip Claw",
    "Choice Scarf",
    "Sticky Barb",
    "Power Bracer",
    "Power Belt",
    "Power Lens",
    "Power Band",
    "Power Anklet",
    "Power Weight",
    "Shed Shell",
    "Big Root",
    "Choice Specs",
    "Flame Plate",
    "Splash Plate",
    "Zap Plate",
    "Meadow Plate",
    "Icicle Plate",
    "Fist Plate",
    "Toxic Plate",
    "Earth Plate",
    "Sky Plate",
    "Mind Plate",
    "Insect Plate",
    "Stone Plate",
    "Spooky Plate",
    "Draco Plate",
    "Dread Plate",
    "Iron Plate",
    "Odd Incense",
    "Rock Incense",
    "Full Incense",
    "Wave Incense",
    "Rose Incense",
    "Luck Incense",
    "Pure Incense",
    "Protector",
    "Electirizer",
    "Magmarizer",
    "Dubious Disc",
    "Reaper Cloth",
    "Razor Claw",
    "Razor Fang",
    "Tm01",
    "Tm02",
    "Tm03",
    "Tm04",
    "Tm05",
    "Tm06",
    "Tm07",
    "Tm08",
    "Tm09",
    "Tm10",
    "Tm11",
    "Tm12",
    "Tm13",
    "Tm14",
    "Tm15",
    "Tm16",
    "Tm17",
    "Tm18",
    "Tm19",
    "Tm20",
    "Tm21",
    "Tm22",
    "Tm23",
    "Tm24",
    "Tm25",
    "Tm26",
    "Tm27",
    "Tm28",
    "Tm29",
    "Tm30",
    "Tm31",
    "Tm32",
    "Tm33",
    "Tm34",
    "Tm35",
    "Tm36",
    "Tm37",
    "Tm38",
    "Tm39",
    "Tm40",
    "Tm41",
    "Tm42",
    "Tm43",
    "Tm44",
    "Tm45",
    "Tm46",
    "Tm47",
    "Tm48",
    "Tm49",
    "Tm50",
    "Tm51",
    "Tm52",
    "Tm53",
    "Tm54",
    "Tm55",
    "Tm56",
    "Tm57",
    "Tm58",
    "Tm59",
    "Tm60",
    "Tm61",
    "Tm62",
    "Tm63",
    "Tm64",
    "Tm65",
    "Tm66",
    "Tm67",
    "Tm68",
    "Tm69",
    "Tm70",
    "Tm71",
    "Tm72",
    "Tm73",
    "Tm74",
    "Tm75",
    "Tm76",
    "Tm77",
    "Tm78",
    "Tm79",
    "Tm80",
    "Tm81",
    "Tm82",
    "Tm83",
    "Tm84",
    "Tm85",
    "Tm86",
    "Tm87",
    "Tm88",
    "Tm89",
    "Tm90",
    "Tm91",
    "Tm92",
    "Hm01",
    "Hm02",
    "Hm03",
    "Hm04",
    "Hm05",
    "Hm06",
    "Hm07",
    "Hm08",
    "Explorer Kit",
    "Loot Sack",
    "Rule Book",
    "Poke Radar",
    "Point Card",
    "Journal",
    "Seal Case",
    "Fashion Case",
    "Seal Bag",
    "Pal Pad",
    "Works Key",
    "Old Charm",
    "Galactic Key",
    "Red Chain",
    "Town Map",
    "Vs Seeker",
    "Coin Case",
    "Old Rod",
    "Good Rod",
    "Super Rod",
    "Sprayduck",
    "Poffin Case",
    "Bicycle",
    "Suite Key",
    "Oaks Letter",
    "Lunar Wing",
    "Member Card",
    "Azure Flute",
    "Ss Ticket",
    "Contest Pass",
    "Magma Stone",
    "Parcel",
    "Coupon 1",
    "Coupon 2",
    "Coupon 3",
    "Storage Key",
    "Secret Potion",
    "Griseous Orb",
    "Vs Recorder",
    "Gracidea",
    "Secret Key",
    "Apricorn Box",
    "Berry Pots",
    "Squirt Bottle",
    "Lure Ball",
    "Level Ball",
    "Moon Ball",
    "Heavy Ball",
    "Fast Ball",
    "Friend Ball",
    "Love Ball",
    "Park Ball",
    "Sport Ball",
    "Red Apricorn",
    "Blue Apricorn",
    "Yellow Apricorn",
    "Green Apricorn",
    "Pink Apricorn",
    "White Apricorn",
    "Black Apricorn",
    "Dowsing Machine",
    "Rage Candy Bar",
    "Red Orb",
    "Blue Orb",
    "Jade Orb",
    "Enigma Stone",
    "Unown Report",
    "Blue Card",
    "Slowpoke Tail",
    "Clear Bell",
    "Card Key",
    "Basement Key",
    "Red Scale",
    "Lost Item",
    "Pass",
    "Machine Part",
    "Silver Wing",
    "Rainbow Wing",
    "Mystery Egg",
    "Gb Sounds",
    "Tidal Bell",
    "Data Card 01",
    "Data Card 02",
    "Data Card 03",
    "Data Card 04",
    "Data Card 05",
    "Data Card 06",
    "Data Card 07",
    "Data Card 08",
    "Data Card 09",
    "Data Card 10",
    "Data Card 11",
    "Data Card 12",
    "Data Card 13",
    "Data Card 14",
    "Data Card 15",
    "Data Card 16",
    "Data Card 17",
    "Data Card 18",
    "Data Card 19",
    "Data Card 20",
    "Data Card 21",
    "Data Card 22",
    "Data Card 23",
    "Data Card 24",
    "Data Card 25",
    "Data Card 26",
    "Data Card 27",
    "Lock Capsule",
    "Photo Album",
    "Orange Mail",
    "Harbor Mail",
    "Glitter Mail",
    "Mech Mail",
    "Wood Mail",
    "Wave Mail",
    "Bead Mail",
    "Shadow Mail",
    "Tropic Mail",
    "Dream Mail",
    "Fab Mail",
    "Retro Mail",
    "Mach Bike",
    "Acro Bike",
    "Wailmer Pail",
    "Devon Goods",
    "Soot Sack",
    "Pokeblock Case",
    "Letter",
    "Eon Ticket",
    "Scanner",
    "Go Goggles",
    "Meteorite",
    "Rm 1 Key",
    "Rm 2 Key",
    "Rm 4 Key",
    "Rm 6 Key",
    "Devon Scope",
    "Oaks Parcel",
    "Poke Flute",
    "Bike Voucher",
    "Gold Teeth",
    "Lift Key",
    "Silph Scope",
    "Fame Checker",
    "Tm Case",
    "Berry Pouch",
    "Teachy Tv",
    "Tri Pass",
    "Rainbow Pass",
    "Tea",
    "Mysticticket",
    "Auroraticket",
    "Powder Jar",
    "Ruby",
    "Sapphire",
    "Magma Emblem",
    "Old Sea Map",
    "Douse Drive",
    "Shock Drive",
    "Burn Drive",
    "Chill Drive",
    "Sweet Heart",
    "Greet Mail",
    "Favored Mail",
    "Rsvp Mail",
    "Thanks Mail",
    "Inquiry Mail",
    "Like Mail",
    "Reply Mail",
    "Bridge Mail S",
    "Bridge Mail D",
    "Bridge Mail T",
    "Bridge Mail V",
    "Bridge Mail M",
    "Prism Scale",
    "Eviolite",
    "Float Stone",
    "Rocky Helmet",
    "Air Balloon",
    "Red Card",
    "Ring Target",
    "Binding Band",
    "Absorb Bulb",
    "Cell Battery",
    "Eject Button",
    "Fire Gem",
    "Water Gem",
    "Electric Gem",
    "Grass Gem",
    "Ice Gem",
    "Fighting Gem",
    "Poison Gem",
    "Ground Gem",
    "Flying Gem",
    "Psychic Gem",
    "Bug Gem",
    "Rock Gem",
    "Ghost Gem",
    "Dark Gem",
    "Steel Gem",
    "Health Wing",
    "Muscle Wing",
    "Resist Wing",
    "Genius Wing",
    "Clever Wing",
    "Swift Wing",
    "Pretty Wing",
    "Cover Fossil",
    "Plume Fossil",
    "Liberty Pass",
    "Pass Orb",
    "Dream Ball",
    "Poke Toy",
    "Prop Case",
    "Dragon Skull",
    "Balm Mushroom",
    "Big Nugget",
    "Pearl String",
    "Comet Shard",
    "Relic Copper",
    "Relic Silver",
    "Relic Gold",
    "Relic Vase",
    "Relic Band",
    "Relic Statue",
    "Relic Crown",
    "Casteliacone",
    "Dire Hit 2",
    "X Speed 2",
    "X Sp Atk 2",
    "X Sp Def 2",
    "X Defense 2",
    "X Attack 2",
    "X Accuracy 2",
    "X Speed 3",
    "X Sp Atk 3",
    "X Sp Def 3",
    "X Defense 3",
    "X Attack 3",
    "X Accuracy 3",
    "X Speed 6",
    "X Sp Atk 6",
    "X Sp Def 6",
    "X Defense 6",
    "X Attack 6",
    "X Accuracy 6",
    "Ability Urge",
    "Item Drop",
    "Item Urge",
    "Reset Urge",
    "Dire Hit 3",
    "Light Stone",
    "Dark Stone",
    "Tm93",
    "Tm94",
    "Tm95",
    "Xtransceiver",
    "God Stone",
    "Gram 1",
    "Gram 2",
    "Gram 3",
    "Dragon Gem",
    "Normal Gem",
    "Medal Box",
    "Dna Splicers",
    "Permit",
    "Oval Charm",
    "Shiny Charm",
    "Plasma Card",
    "Grubby Hanky",
    "Colress Machine",
    "Dropped Item",
    "Reveal Glass",
    "Weakness Policy",
    "Assault Vest",
    "Pixie Plate",
    "Ability Capsule",
    "Whipped Dream",
    "Sachet",
    "Luminous Moss",
    "Snowball",
    "Safety Goggles",
    "Rich Mulch",
    "Surprise Mulch",
    "Boost Mulch",
    "Amaze Mulch",
    "Gengarite",
    "Gardevoirite",
    "Ampharosite",
    "Venusaurite",
    "Charizardite X",
    "Blastoisinite",
    "Mewtwonite X",
    "Mewtwonite Y",
    "Blazikenite",
    "Medichamite",
    "Houndoominite",
    "Aggronite",
    "Banettite",
    "Tyranitarite",
    "Scizorite",
    "Pinsirite",
    "Aerodactylite",
    "Lucarionite",
    "Abomasite",
    "Kangaskhanite",
    "Gyaradosite",
    "Absolite",
    "Charizardite Y",
    "Alakazite",
    "Heracronite",
    "Mawilite",
    "Manectite",
    "Garchompite",
    "Roseli Berry",
    "Kee Berry",
    "Maranga Berry",
    "Discount Coupon",
    "Strange Souvenir",
    "Lumiose Galette",
    "Jaw Fossil",
    "Sail Fossil",
    "Fairy Gem",
    "Adventure Rules",
    "Elevator Key",
    "Holo Caster",
    "Honor Of Kalos",
    "Intriguing Stone",
    "Lens Case",
    "Looker Ticket",
    "Mega Ring",
    "Power Plant Pass",
    "Profs Letter",
    "Roller Skates",
    "Sprinklotad",
    "Tmv Pass",
    "Tm96",
    "Tm97",
    "Tm98",
    "Tm99",
    "Tm100",
    "Latiasite",
    "Latiosite",
    "Common Stone",
    "Makeup Bag",
    "Travel Trunk",
    "Shalour Sable",
    "Mega Charm",
    "Mega Glove",
    "Devon Parts",
    "Pokeblock Kit",
    "Key To Room 1",
    "Key To Room 2",
    "Key To Room 4",
    "Key To Room 6",
    "Devon Scuba Gear",
    "Contest Costume  Jacket",
    "Magma Suit",
    "Aqua Suit",
    "Pair Of Tickets",
    "Mega Bracelet",
    "Mega Pendant",
    "Mega Glasses",
    "Mega Anchor",
    "Mega Stickpin",
    "Mega Tiara",
    "Mega Anklet",
    "Swampertite",
    "Sceptilite",
    "Sablenite",
    "Altarianite",
    "Galladite",
    "Audinite",
    "Metagrossite",
    "Sharpedonite",
    "Slowbronite",
    "Steelixite",
    "Pidgeotite",
    "Glalitite",
    "Diancite",
    "Prison Bottle",
    "Mega Cuff",
    "Cameruptite",
    "Lopunnite",
    "Salamencite",
    "Beedrillite",
    "Key Stone",
    "Meteorite Shard",
    "Eon Flute",
    "Normalium Z  Held",
    "Firium Z  Held",
    "Waterium Z  Held",
    "Electrium Z  Held",
    "Grassium Z  Held",
    "Icium Z  Held",
    "Fightinium Z  Held",
    "Poisonium Z  Held",
    "Groundium Z  Held",
    "Flyinium Z  Held",
    "Psychium Z  Held",
    "Buginium Z  Held",
    "Rockium Z  Held",
    "Ghostium Z  Held",
    "Dragonium Z  Held",
    "Darkinium Z  Held",
    "Steelium Z  Held",
    "Fairium Z  Held",
    "Pikanium Z  Held",
    "Bottle Cap",
    "Gold Bottle Cap",
    "Z Ring",
    "Decidium Z  Held",
    "Incinium Z  Held",
    "Primarium Z  Held",
    "Tapunium Z  Held",
    "Marshadium Z  Held",
    "Aloraichium Z  Held",
    "Snorlium Z  Held",
    "Eevium Z  Held",
    "Mewnium Z  Held",
    "Pikashunium Z  Held",
    "Forage Bag",
    "Fishing Rod",
    "Professors Mask",
    "Festival Ticket",
    "Sparkling Stone",
    "Adrenaline Orb",
    "Zygarde Cube",
    "Ice Stone",
    "Ride Pager",
    "Beast Ball",
    "Big Malasada",
    "Red Nectar",
    "Yellow Nectar",
    "Pink Nectar",
    "Purple Nectar",
    "Sun Flute",
    "Moon Flute",
    "Enigmatic Card",
    "Terrain Extender",
    "Protective Pads",
    "Electric Seed",
    "Psychic Seed",
    "Misty Seed",
    "Grassy Seed",
    "Fighting Memory",
    "Flying Memory",
    "Poison Memory",
    "Ground Memory",
    "Rock Memory",
    "Bug Memory",
    "Ghost Memory",
    "Steel Memory",
    "Fire Memory",
    "Water Memory",
    "Grass Memory",
    "Electric Memory",
    "Psychic Memory",
    "Ice Memory",
    "Dragon Memory",
    "Dark Memory",
    "Fairy Memory",
    "Bike  Green",
    "Storage Key  Galactic Warehouse",
    "Basement Key  Goldenrod",
    "Xtransceiver  Red",
    "Xtransceiver  Yellow",
    "Dna Splicers  Merge",
    "Dna Splicers  Split",
    "Dropped Item  Red",
    "Dropped Item  Yellow",
    "Holo Caster  Green",
    "Bike  Yellow",
    "Holo Caster  Red",
    "Basement Key  New Mauville",
    "Storage Key  Sea Mauville",
    "Ss Ticket  Hoenn",
    "Contest Costume  Dress",
    "Meteorite  2",
    "Meteorite  3",
    "Meteorite  4",
    "Normalium Z  Bag",
    "Firium Z  Bag",
    "Waterium Z  Bag",
    "Electrium Z  Bag",
    "Grassium Z  Bag",
    "Icium Z  Bag",
    "Fightinium Z  Bag",
    "Poisonium Z  Bag",
    "Groundium Z  Bag",
    "Flyinium Z  Bag",
    "Psychium Z  Bag",
    "Buginium Z  Bag",
    "Rockium Z  Bag",
    "Ghostium Z  Bag",
    "Dragonium Z  Bag",
    "Darkinium Z  Bag",
    "Steelium Z  Bag",
    "Fairium Z  Bag",
    "Pikanium Z  Bag",
    "Decidium Z  Bag",
    "Incinium Z  Bag",
    "Primarium Z  Bag",
    "Tapunium Z  Bag",
    "Marshadium Z  Bag",
    "Aloraichium Z  Bag",
    "Snorlium Z  Bag",
    "Eevium Z  Bag",
    "Mewnium Z  Bag",
    "Pikashunium Z  Bag",
    "Solganium Z  Held",
    "Lunalium Z  Held",
    "Ultranecrozium Z  Held",
    "Mimikium Z  Held",
    "Lycanium Z  Held",
    "Kommonium Z  Held",
    "Solganium Z  Bag",
    "Lunalium Z  Bag",
    "Ultranecrozium Z  Bag",
    "Mimikium Z  Bag",
    "Lycanium Z  Bag",
    "Kommonium Z  Bag",
    "Z Power Ring",
    "Pink Petal",
    "Orange Petal",
    "Blue Petal",
    "Red Petal",
    "Green Petal",
    "Yellow Petal",
    "Purple Petal",
    "Rainbow Flower",
    "Surge Badge",
    "N Solarizer  Merge",
    "N Lunarizer  Merge",
    "N Solarizer  Split",
    "N Lunarizer  Split",
    "Ilimas Normalium Z",
    "Left Poke Ball",
    "Roto Hatch",
    "Roto Bargain",
    "Roto Prize Money",
    "Roto Exp Points",
    "Roto Friendship",
    "Roto Encounter",
    "Roto Stealth",
    "Roto Hp Restore",
    "Roto Pp Restore",
    "Roto Boost",
    "Roto Catch",
    "Autograph",
    "Pokemon Box",
    "Medicine Pocket",
    "Candy Jar",
    "Power Up Pocket",
    "Clothing Trunk",
    "Catching Pocket",
    "Battle Pocket",
    "Silver Razz Berry",
    "Golden Razz Berry",
    "Silver Nanab Berry",
    "Golden Nanab Berry",
    "Silver Pinap Berry",
    "Golden Pinap Berry",
    "Secret Key  Letsgo",
    "Ss Ticket  Letsgo",
    "Parcel  Letsgo",
    "Card Key  Letsgo",
    "Stretchy Spring",
    "Chalky Stone",
    "Marble",
    "Lone Earring",
    "Beach Glass",
    "Gold Leaf",
    "Silver Leaf",
    "Polished Mud Ball",
    "Tropical Shell",
    "Leaf Letter  Pikachu",
    "Leaf Letter  Eevee",
    "Small Bouquet",
    "Lure",
    "Super Lure",
    "Max Lure",
    "Pewter Crunchies",
    "Health Candy",
    "Mighty Candy",
    "Tough Candy",
    "Smart Candy",
    "Courage Candy",
    "Quick Candy",
    "Health Candy L",
    "Mighty Candy L",
    "Tough Candy L",
    "Smart Candy L",
    "Courage Candy L",
    "Quick Candy L",
    "Health Candy Xl",
    "Mighty Candy Xl",
    "Tough Candy Xl",
    "Smart Candy Xl",
    "Courage Candy Xl",
    "Quick Candy Xl",
    "Bulbasaur Candy",
    "Charmander Candy",
    "Squirtle Candy",
    "Caterpie Candy",
    "Weedle Candy",
    "Pidgey Candy",
    "Rattata Candy",
    "Spearow Candy",
    "Ekans Candy",
    "Pikachu Candy",
    "Sandshrew Candy",
    "Nidoran F Candy",
    "Nidoran M Candy",
    "Clefairy Candy",
    "Vulpix Candy",
    "Jigglypuff Candy",
    "Zubat Candy",
    "Oddish Candy",
    "Paras Candy",
    "Venonat Candy",
    "Diglett Candy",
    "Meowth Candy",
    "Psyduck Candy",
    "Mankey Candy",
    "Growlithe Candy",
    "Poliwag Candy",
    "Abra Candy",
    "Machop Candy",
    "Bellsprout Candy",
    "Tentacool Candy",
    "Geodude Candy",
    "Ponyta Candy",
    "Slowpoke Candy",
    "Magnemite Candy",
    "Farfetchd Candy",
    "Doduo Candy",
    "Seel Candy",
    "Grimer Candy",
    "Shellder Candy",
    "Gastly Candy",
    "Onix Candy",
    "Drowzee Candy",
    "Krabby Candy",
    "Voltorb Candy",
    "Exeggcute Candy",
    "Cubone Candy",
    "Hitmonlee Candy",
    "Hitmonchan Candy",
    "Lickitung Candy",
    "Koffing Candy",
    "Rhyhorn Candy",
    "Chansey Candy",
    "Tangela Candy",
    "Kangaskhan Candy",
    "Horsea Candy",
    "Goldeen Candy",
    "Staryu Candy",
    "Mr Mime Candy",
    "Scyther Candy",
    "Jynx Candy",
    "Electabuzz Candy",
    "Pinsir Candy",
    "Tauros Candy",
    "Magikarp Candy",
    "Lapras Candy",
    "Ditto Candy",
    "Eevee Candy",
    "Porygon Candy",
    "Omanyte Candy",
    "Kabuto Candy",
    "Aerodactyl Candy",
    "Snorlax Candy",
    "Articuno Candy",
    "Zapdos Candy",
    "Moltres Candy",
    "Dratini Candy",
    "Mewtwo Candy",
    "Mew Candy",
    "Meltan Candy",
    "Magmar Candy",
    "Endorsement",
    "Pokemon Box Link",
    "Wishing Star",
    "Dynamax Band",
    "Fishing Rod  Galar",
    "Rotom Bike",
    "Sausages",
    "Bobs Food Tin",
    "Bachs Food Tin",
    "Tin Of Beans",
    "Bread",
    "Pasta",
    "Mixed Mushrooms",
    "Smoke Poke Tail",
    "Large Leek",
    "Fancy Apple",
    "Brittle Bones",
    "Pack Of Potatoes",
    "Pungent Root",
    "Salad Mix",
    "Fried Food",
    "Boiled Egg",
    "Camping Gear",
    "Rusted Sword",
    "Rusted Shield",
    "Fossilized Bird",
    "Fossilized Fish",
    "Fossilized Drake",
    "Fossilized Dino",
    "Strawberry Sweet",
    "Love Sweet",
    "Berry Sweet",
    "Clover Sweet",
    "Flower Sweet",
    "Star Sweet",
    "Ribbon Sweet",
    "Sweet Apple",
    "Tart Apple",
    "Throat Spray",
    "Eject Pack",
    "Heavy Duty Boots",
    "Blunder Policy",
    "Room Service",
    "Utility Umbrella",
    "Exp Candy Xs",
    "Exp Candy S",
    "Exp Candy M",
    "Exp Candy L",
    "Exp Candy Xl",
    "Dynamax Candy",
    "Tr00",
    "Tr01",
    "Tr02",
    "Tr03",
    "Tr04",
    "Tr05",
    "Tr06",
    "Tr07",
    "Tr08",
    "Tr09",
    "Tr10",
    "Tr11",
    "Tr12",
    "Tr13",
    "Tr14",
    "Tr15",
    "Tr16",
    "Tr17",
    "Tr18",
    "Tr19",
    "Tr20",
    "Tr21",
    "Tr22",
    "Tr23",
    "Tr24",
    "Tr25",
    "Tr26",
    "Tr27",
    "Tr28",
    "Tr29",
    "Tr30",
    "Tr31",
    "Tr32",
    "Tr33",
    "Tr34",
    "Tr35",
    "Tr36",
    "Tr37",
    "Tr38",
    "Tr39",
    "Tr40",
    "Tr41",
    "Tr42",
    "Tr43",
    "Tr44",
    "Tr45",
    "Tr46",
    "Tr47",
    "Tr48",
    "Tr49",
    "Tr50",
    "Tr51",
    "Tr52",
    "Tr53",
    "Tr54",
    "Tr55",
    "Tr56",
    "Tr57",
    "Tr58",
    "Tr59",
    "Tr60",
    "Tr61",
    "Tr62",
    "Tr63",
    "Tr64",
    "Tr65",
    "Tr66",
    "Tr67",
    "Tr68",
    "Tr69",
    "Tr70",
    "Tr71",
    "Tr72",
    "Tr73",
    "Tr74",
    "Tr75",
    "Tr76",
    "Tr77",
    "Tr78",
    "Tr79",
    "Tr80",
    "Tr81",
    "Tr82",
    "Tr83",
    "Tr84",
    "Tr85",
    "Tr86",
    "Tr87",
    "Tr88",
    "Tr89",
    "Tr90",
    "Tr91",
    "Tr92",
    "Tr93",
    "Tr94",
    "Tr95",
    "Tr96",
    "Tr97",
    "Tr98",
    "Tr99",
    "Tm00",
    "Lonely Mint",
    "Adamant Mint",
    "Naughty Mint",
    "Brave Mint",
    "Bold Mint",
    "Impish Mint",
    "Lax Mint",
    "Relaxed Mint",
    "Modest Mint",
    "Mild Mint",
    "Rash Mint",
    "Quiet Mint",
    "Calm Mint",
    "Gentle Mint",
    "Careful Mint",
    "Sassy Mint",
    "Timid Mint",
    "Hasty Mint",
    "Jolly Mint",
    "Naive Mint",
    "Serious Mint",
    "Wishing Piece",
    "Cracked Pot",
    "Chipped Pot",
    "Hi Tech Earbuds",
    "Fruit Bunch",
    "Moomoo Cheese",
    "Spice Mix",
    "Fresh Cream",
    "Packaged Curry",
    "Coconut Milk",
    "Instant Noodles",
    "Precooked Burger",
    "Gigantamix",
    "Wishing Chip",
    "Rotom Bike  Water Mode",
    "Catching Charm",
    "Old Letter",
    "Band Autograph",
    "Sonias Book",
    "Rotom Catalog",
    "Dynamax Crystal And458",
    "Dynamax Crystal And15",
    "Dynamax Crystal And337",
    "Dynamax Crystal And603",
    "Dynamax Crystal And390",
    "Dynamax Crystal Sgr6879",
    "Dynamax Crystal Sgr6859",
    "Dynamax Crystal Sgr6913",
    "Dynamax Crystal Sgr7348",
    "Dynamax Crystal Sgr7121",
    "Dynamax Crystal Sgr6746",
    "Dynamax Crystal Sgr7194",
    "Dynamax Crystal Sgr7337",
    "Dynamax Crystal Sgr7343",
    "Dynamax Crystal Sgr6812",
    "Dynamax Crystal Sgr7116",
    "Dynamax Crystal Sgr7264",
    "Dynamax Crystal Sgr7597",
    "Dynamax Crystal Del7882",
    "Dynamax Crystal Del7906",
    "Dynamax Crystal Del7852",
    "Dynamax Crystal Psc596",
    "Dynamax Crystal Psc361",
    "Dynamax Crystal Psc510",
    "Dynamax Crystal Psc437",
    "Dynamax Crystal Psc8773",
    "Dynamax Crystal Lep1865",
    "Dynamax Crystal Lep1829",
    "Dynamax Crystal Boo5340",
    "Dynamax Crystal Boo5506",
    "Dynamax Crystal Boo5435",
    "Dynamax Crystal Boo5602",
    "Dynamax Crystal Boo5733",
    "Dynamax Crystal Boo5235",
    "Dynamax Crystal Boo5351",
    "Dynamax Crystal Hya3748",
    "Dynamax Crystal Hya3903",
    "Dynamax Crystal Hya3418",
    "Dynamax Crystal Hya3482",
    "Dynamax Crystal Hya3845",
    "Dynamax Crystal Eri1084",
    "Dynamax Crystal Eri472",
    "Dynamax Crystal Eri1666",
    "Dynamax Crystal Eri897",
    "Dynamax Crystal Eri1231",
    "Dynamax Crystal Eri874",
    "Dynamax Crystal Eri1298",
    "Dynamax Crystal Eri1325",
    "Dynamax Crystal Eri984",
    "Dynamax Crystal Eri1464",
    "Dynamax Crystal Eri1393",
    "Dynamax Crystal Eri850",
    "Dynamax Crystal Tau1409",
    "Dynamax Crystal Tau1457",
    "Dynamax Crystal Tau1165",
    "Dynamax Crystal Tau1791",
    "Dynamax Crystal Tau1910",
    "Dynamax Crystal Tau1346",
    "Dynamax Crystal Tau1373",
    "Dynamax Crystal Tau1412",
    "Dynamax Crystal Cma2491",
    "Dynamax Crystal Cma2693",
    "Dynamax Crystal Cma2294",
    "Dynamax Crystal Cma2827",
    "Dynamax Crystal Cma2282",
    "Dynamax Crystal Cma2618",
    "Dynamax Crystal Cma2657",
    "Dynamax Crystal Cma2646",
    "Dynamax Crystal Uma4905",
    "Dynamax Crystal Uma4301",
    "Dynamax Crystal Uma5191",
    "Dynamax Crystal Uma5054",
    "Dynamax Crystal Uma4295",
    "Dynamax Crystal Uma4660",
    "Dynamax Crystal Uma4554",
    "Dynamax Crystal Uma4069",
    "Dynamax Crystal Uma3569",
    "Dynamax Crystal Uma3323",
    "Dynamax Crystal Uma4033",
    "Dynamax Crystal Uma4377",
    "Dynamax Crystal Uma4375",
    "Dynamax Crystal Uma4518",
    "Dynamax Crystal Uma3594",
    "Dynamax Crystal Vir5056",
    "Dynamax Crystal Vir4825",
    "Dynamax Crystal Vir4932",
    "Dynamax Crystal Vir4540",
    "Dynamax Crystal Vir4689",
    "Dynamax Crystal Vir5338",
    "Dynamax Crystal Vir4910",
    "Dynamax Crystal Vir5315",
    "Dynamax Crystal Vir5359",
    "Dynamax Crystal Vir5409",
    "Dynamax Crystal Vir5107",
    "Dynamax Crystal Ari617",
    "Dynamax Crystal Ari553",
    "Dynamax Crystal Ari546",
    "Dynamax Crystal Ari951",
    "Dynamax Crystal Ori1713",
    "Dynamax Crystal Ori2061",
    "Dynamax Crystal Ori1790",
    "Dynamax Crystal Ori1903",
    "Dynamax Crystal Ori1948",
    "Dynamax Crystal Ori2004",
    "Dynamax Crystal Ori1852",
    "Dynamax Crystal Ori1879",
    "Dynamax Crystal Ori1899",
    "Dynamax Crystal Ori1543",
    "Dynamax Crystal Cas21",
    "Dynamax Crystal Cas168",
    "Dynamax Crystal Cas403",
    "Dynamax Crystal Cas153",
    "Dynamax Crystal Cas542",
    "Dynamax Crystal Cas219",
    "Dynamax Crystal Cas265",
    "Dynamax Crystal Cnc3572",
    "Dynamax Crystal Cnc3208",
    "Dynamax Crystal Cnc3461",
    "Dynamax Crystal Cnc3449",
    "Dynamax Crystal Cnc3429",
    "Dynamax Crystal Cnc3627",
    "Dynamax Crystal Cnc3268",
    "Dynamax Crystal Cnc3249",
    "Dynamax Crystal Com4968",
    "Dynamax Crystal Crv4757",
    "Dynamax Crystal Crv4623",
    "Dynamax Crystal Crv4662",
    "Dynamax Crystal Crv4786",
    "Dynamax Crystal Aur1708",
    "Dynamax Crystal Aur2088",
    "Dynamax Crystal Aur1605",
    "Dynamax Crystal Aur2095",
    "Dynamax Crystal Aur1577",
    "Dynamax Crystal Aur1641",
    "Dynamax Crystal Aur1612",
    "Dynamax Crystal Pav7790",
    "Dynamax Crystal Cet911",
    "Dynamax Crystal Cet681",
    "Dynamax Crystal Cet188",
    "Dynamax Crystal Cet539",
    "Dynamax Crystal Cet804",
    "Dynamax Crystal Cep8974",
    "Dynamax Crystal Cep8162",
    "Dynamax Crystal Cep8238",
    "Dynamax Crystal Cep8417",
    "Dynamax Crystal Cen5267",
    "Dynamax Crystal Cen5288",
    "Dynamax Crystal Cen551",
    "Dynamax Crystal Cen5459",
    "Dynamax Crystal Cen5460",
    "Dynamax Crystal Cmi2943",
    "Dynamax Crystal Cmi2845",
    "Dynamax Crystal Equ8131",
    "Dynamax Crystal Vul7405",
    "Dynamax Crystal Umi424",
    "Dynamax Crystal Umi5563",
    "Dynamax Crystal Umi5735",
    "Dynamax Crystal Umi6789",
    "Dynamax Crystal Crt4287",
    "Dynamax Crystal Lyr7001",
    "Dynamax Crystal Lyr7178",
    "Dynamax Crystal Lyr7106",
    "Dynamax Crystal Lyr7298",
    "Dynamax Crystal Ara6585",
    "Dynamax Crystal Sco6134",
    "Dynamax Crystal Sco6527",
    "Dynamax Crystal Sco6553",
    "Dynamax Crystal Sco5953",
    "Dynamax Crystal Sco5984",
    "Dynamax Crystal Sco6508",
    "Dynamax Crystal Sco6084",
    "Dynamax Crystal Sco5944",
    "Dynamax Crystal Sco6630",
    "Dynamax Crystal Sco6027",
    "Dynamax Crystal Sco6247",
    "Dynamax Crystal Sco6252",
    "Dynamax Crystal Sco5928",
    "Dynamax Crystal Sco6241",
    "Dynamax Crystal Sco6165",
    "Dynamax Crystal Tri544",
    "Dynamax Crystal Leo3982",
    "Dynamax Crystal Leo4534",
    "Dynamax Crystal Leo4357",
    "Dynamax Crystal Leo4057",
    "Dynamax Crystal Leo4359",
    "Dynamax Crystal Leo4031",
    "Dynamax Crystal Leo3852",
    "Dynamax Crystal Leo3905",
    "Dynamax Crystal Leo3773",
    "Dynamax Crystal Gru8425",
    "Dynamax Crystal Gru8636",
    "Dynamax Crystal Gru8353",
    "Dynamax Crystal Lib5685",
    "Dynamax Crystal Lib5531",
    "Dynamax Crystal Lib5787",
    "Dynamax Crystal Lib5603",
    "Dynamax Crystal Pup3165",
    "Dynamax Crystal Pup3185",
    "Dynamax Crystal Pup3045",
    "Dynamax Crystal Cyg7924",
    "Dynamax Crystal Cyg7417",
    "Dynamax Crystal Cyg7796",
    "Dynamax Crystal Cyg8301",
    "Dynamax Crystal Cyg7949",
    "Dynamax Crystal Cyg7528",
    "Dynamax Crystal Oct7228",
    "Dynamax Crystal Col1956",
    "Dynamax Crystal Col2040",
    "Dynamax Crystal Col2177",
    "Dynamax Crystal Gem2990",
    "Dynamax Crystal Gem2891",
    "Dynamax Crystal Gem2421",
    "Dynamax Crystal Gem2473",
    "Dynamax Crystal Gem2216",
    "Dynamax Crystal Gem2777",
    "Dynamax Crystal Gem2650",
    "Dynamax Crystal Gem2286",
    "Dynamax Crystal Gem2484",
    "Dynamax Crystal Gem2930",
    "Dynamax Crystal Peg8775",
    "Dynamax Crystal Peg8781",
    "Dynamax Crystal Peg39",
    "Dynamax Crystal Peg8308",
    "Dynamax Crystal Peg8650",
    "Dynamax Crystal Peg8634",
    "Dynamax Crystal Peg8684",
    "Dynamax Crystal Peg8450",
    "Dynamax Crystal Peg8880",
    "Dynamax Crystal Peg8905",
    "Dynamax Crystal Oph6556",
    "Dynamax Crystal Oph6378",
    "Dynamax Crystal Oph6603",
    "Dynamax Crystal Oph6149",
    "Dynamax Crystal Oph6056",
    "Dynamax Crystal Oph6075",
    "Dynamax Crystal Ser5854",
    "Dynamax Crystal Ser7141",
    "Dynamax Crystal Ser5879",
    "Dynamax Crystal Her6406",
    "Dynamax Crystal Her6148",
    "Dynamax Crystal Her6410",
    "Dynamax Crystal Her6526",
    "Dynamax Crystal Her6117",
    "Dynamax Crystal Her6008",
    "Dynamax Crystal Per936",
    "Dynamax Crystal Per1017",
    "Dynamax Crystal Per1131",
    "Dynamax Crystal Per1228",
    "Dynamax Crystal Per834",
    "Dynamax Crystal Per941",
    "Dynamax Crystal Phe99",
    "Dynamax Crystal Phe338",
    "Dynamax Crystal Vel3634",
    "Dynamax Crystal Vel3485",
    "Dynamax Crystal Vel3734",
    "Dynamax Crystal Aqr8232",
    "Dynamax Crystal Aqr8414",
    "Dynamax Crystal Aqr8709",
    "Dynamax Crystal Aqr8518",
    "Dynamax Crystal Aqr7950",
    "Dynamax Crystal Aqr8499",
    "Dynamax Crystal Aqr8610",
    "Dynamax Crystal Aqr8264",
    "Dynamax Crystal Cru4853",
    "Dynamax Crystal Cru4730",
    "Dynamax Crystal Cru4763",
    "Dynamax Crystal Cru4700",
    "Dynamax Crystal Cru4656",
    "Dynamax Crystal Psa8728",
    "Dynamax Crystal Tra6217",
    "Dynamax Crystal Cap7776",
    "Dynamax Crystal Cap7754",
    "Dynamax Crystal Cap8278",
    "Dynamax Crystal Cap8322",
    "Dynamax Crystal Cap7773",
    "Dynamax Crystal Sge7479",
    "Dynamax Crystal Car2326",
    "Dynamax Crystal Car3685",
    "Dynamax Crystal Car3307",
    "Dynamax Crystal Car3699",
    "Dynamax Crystal Dra5744",
    "Dynamax Crystal Dra5291",
    "Dynamax Crystal Dra6705",
    "Dynamax Crystal Dra6536",
    "Dynamax Crystal Dra7310",
    "Dynamax Crystal Dra6688",
    "Dynamax Crystal Dra4434",
    "Dynamax Crystal Dra6370",
    "Dynamax Crystal Dra7462",
    "Dynamax Crystal Dra6396",
    "Dynamax Crystal Dra6132",
    "Dynamax Crystal Dra6636",
    "Dynamax Crystal Cvn4915",
    "Dynamax Crystal Cvn4785",
    "Dynamax Crystal Cvn4846",
    "Dynamax Crystal Aql7595",
    "Dynamax Crystal Aql7557",
    "Dynamax Crystal Aql7525",
    "Dynamax Crystal Aql7602",
    "Dynamax Crystal Aql7235",
    "Max Honey",
    "Max Mushrooms",
    "Galarica Twig",
    "Galarica Cuff",
    "Style Card",
    "Armor Pass",
    "Rotom Bike  Sparkling White",
    "Rotom Bike  Glistening Black",
    "Exp Charm",
    "Armorite Ore",
    "Mark Charm",
    "Reins Of Unity  Merge",
    "Reins Of Unity  Split",
    "Galarica Wreath",
    "Legendary Clue 1",
    "Legendary Clue 2",
    "Legendary Clue 3",
    "Legendary Clue Question",
    "Crown Pass",
    "Wooden Crown",
    "Radiant Petal",
    "White Mane Hair",
    "Black Mane Hair",
    "Iceroot Carrot",
    "Shaderoot Carrot",
    "Dynite Ore",
    "Carrot Seeds",
    "Ability Patch",
    "Reins Of Unity",
    "Adamant Crystal",
    "Lustrous Globe",
    "Griseous Core",
    "Blank Plate",
    "Strange Ball",
    "Legend Plate",
    "Rotom Phone",
    "Sandwich",
    "Koraidons Poke Ball",
    "Miraidons Poke Ball",
    "Tera Orb",
    "Scarlet Book",
    "Violet Book",
    "Kofu’S Wallet",
    "Tiny Bamboo Shoot",
    "Big Bamboo Shoot",
    "Scroll Of Darkness",
    "Scroll Of Waters",
    "Malicious Armor",
    "Normal Tera Shard",
    "Fire Tera Shard",
    "Water Tera Shard",
    "Electric Tera Shard",
    "Grass Tera Shard",
    "Ice Tera Shard",
    "Fighting Tera Shard",
    "Poison Tera Shard",
    "Ground Tera Shard",
    "Flying Tera Shard",
    "Psychic Tera Shard",
    "Bug Tera Shard",
    "Rock Tera Shard",
    "Ghost Tera Shard",
    "Dragon Tera Shard",
    "Dark Tera Shard",
    "Steel Tera Shard",
    "Fairy Tera Shard",
    "Booster Energy",
    "Ability Shield",
    "Clear Amulet",
    "Mirror Herb",
    "Punching Glove",
    "Covert Cloak",
    "Loaded Dice",
    "Baguette",
    "Mayonnaise",
    "Ketchup",
    "Mustard",
    "Butter",
    "Peanut Butter",
    "Chili Sauce",
    "Salt",
    "Pepper",
    "Yogurt",
    "Whipped Cream",
    "Cream Cheese",
    "Jam",
    "Marmalade",
    "Olive Oil",
    "Vinegar",
    "Sweet Herba Mystica",
    "Salty Herba Mystica",
    "Sour Herba Mystica",
    "Bitter Herba Mystica",
    "Spicy Herba Mystica",
    "Lettuce",
    "Tomato",
    "Cherry Tomatoes",
    "Cucumber",
    "Pickle",
    "Onion",
    "Red Onion",
    "Green Bell Pepper",
    "Red Bell Pepper",
    "Yellow Bell Pepper",
    "Avocado",
    "Bacon",
    "Ham",
    "Prosciutto",
    "Chorizo",
    "Herbed Sausage",
    "Hamburger",
    "Klawf Stick",
    "Smoked Fillet",
    "Fried Fillet",
    "Egg",
    "Potato Tortilla",
    "Tofu",
    "Rice",
    "Noodles",
    "Potato Salad",
    "Cheese",
    "Banana",
    "Strawberry",
    "Apple",
    "Kiwi",
    "Pineapple",
    "Jalapeño",
    "Horseradish",
    "Curry Powder",
    "Wasabi",
    "Watercress",
    "Basil",
    "Venonat Fang",
    "Diglett Dirt",
    "Meowth Fur",
    "Psyduck Down",
    "Mankey Fur",
    "Growlithe Fur",
    "Slowpoke Claw",
    "Magnemite Screw",
    "Grimer Toxin",
    "Shellder Pearl",
    "Gastly Gas",
    "Drowzee Fur",
    "Voltorb Sparks",
    "Scyther Claw",
    "Tauros Hair",
    "Magikarp Scales",
    "Ditto Goo",
    "Eevee Fur",
    "Dratini Scales",
    "Pichu Fur",
    "Igglybuff Fluff",
    "Mareep Wool",
    "Hoppip Leaf",
    "Sunkern Leaf",
    "Murkrow Bauble",
    "Misdreavus Tears",
    "Girafarig Fur",
    "Pineco Husk",
    "Dunsparce Scales",
    "Qwilfish Spines",
    "Heracross Claw",
    "Sneasel Claw",
    "Teddiursa Claw",
    "Delibird Parcel",
    "Houndour Fang",
    "Phanpy Nail",
    "Stantler Hair",
    "Larvitar Claw",
    "Wingull Feather",
    "Ralts Dust",
    "Surskit Syrup",
    "Shroomish Spores",
    "Slakoth Fur",
    "Makuhita Sweat",
    "Azurill Fur",
    "Sableye Gem",
    "Meditite Sweat",
    "Gulpin Mucus",
    "Numel Lava",
    "Torkoal Coal",
    "Spoink Pearl",
    "Cacnea Needle",
    "Swablu Fluff",
    "Zangoose Claw",
    "Seviper Fang",
    "Barboach Slime",
    "Shuppet Scrap",
    "Tropius Leaf",
    "Snorunt Fur",
    "Luvdisc Scales",
    "Bagon Scales",
    "Starly Feather",
    "Kricketot Shell",
    "Shinx Fang",
    "Combee Honey",
    "Pachirisu Fur",
    "Buizel Fur",
    "Shellos Mucus",
    "Drifloon Gas",
    "Stunky Fur",
    "Bronzor Fragment",
    "Bonsly Tears",
    "Happiny Dust",
    "Spiritomb Fragment",
    "Gible Scales",
    "Riolu Fur",
    "Hippopotas Sand",
    "Croagunk Poison",
    "Finneon Scales",
    "Snover Berries",
    "Rotom Sparks",
    "Petilil Leaf",
    "Basculin Fang",
    "Sandile Claw",
    "Zorua Fur",
    "Gothita Eyelash",
    "Deerling Hair",
    "Foongus Spores",
    "Alomomola Mucus",
    "Tynamo Slime",
    "Axew Scales",
    "Cubchoo Fur",
    "Cryogonal Ice",
    "Pawniard Blade",
    "Rufflet Feather",
    "Deino Scales",
    "Larvesta Fuzz",
    "Fletchling Feather",
    "Scatterbug Powder",
    "Litleo Tuft",
    "Flabebe Pollen",
    "Skiddo Leaf",
    "Skrelp Kelp",
    "Clauncher Claw",
    "Hawlucha Down",
    "Dedenne Fur",
    "Goomy Goo",
    "Klefki Key",
    "Bergmite Ice",
    "Noibat Fur",
    "Yungoos Fur",
    "Crabrawler Shell",
    "Oricorio Feather",
    "Rockruff Rock",
    "Mareanie Spike",
    "Mudbray Mud",
    "Fomantis Leaf",
    "Salandit Gas",
    "Bounsweet Sweat",
    "Oranguru Fur",
    "Passimian Fur",
    "Sandygast Sand",
    "Komala Claw",
    "Mimikyu Scrap",
    "Bruxish Tooth",
    "Chewtle Claw",
    "Skwovet Fur",
    "Arrokuda Scales",
    "Rookidee Feather",
    "Toxel Sparks",
    "Falinks Sweat",
    "Cufant Tarnish",
    "Rolycoly Coal",
    "Silicobra Sand",
    "Indeedee Fur",
    "Pincurchin Spines",
    "Snom Thread",
    "Impidimp Hair",
    "Applin Juice",
    "Sinistea Chip",
    "Hatenna Dust",
    "Stonjourner Stone",
    "Eiscue Down",
    "Dreepy Powder",
    "Lechonk Hair",
    "Tarountula Thread",
    "Nymble Claw",
    "Rellor Mud",
    "Greavard Wax",
    "Flittle Down",
    "Wiglett Sand",
    "Dondozo Whisker",
    "Veluza Fillet",
    "Finizen Mucus",
    "Smoliv Oil",
    "Capsakid Seed",
    "Tadbulb Mucus",
    "Varoom Fume",
    "Orthworm Tarnish",
    "Tandemaus Fur",
    "Cetoddle Grease",
    "Frigibax Scales",
    "Tatsugiri Scales",
    "Cyclizar Scales",
    "Pawmi Fur",
    "Wattrel Feather",
    "Bombirdier Feather",
    "Squawkabilly Feather",
    "Flamigo Down",
    "Klawf Claw",
    "Nacli Salt",
    "Glimmet Crystal",
    "Shroodle Ink",
    "Fidough Fur",
    "Maschiff Fang",
    "Bramblin Twig",
    "Gimmighoul Coin",
    "Tinkatink Hair",
    "Charcadet Soot",
    "Toedscool Flaps",
    "Wooper Slime",
    "Tm100",
    "Tm101",
    "Tm102",
    "Tm103",
    "Tm104",
    "Tm105",
    "Tm106",
    "Tm107",
    "Tm108",
    "Tm109",
    "Tm110",
    "Tm111",
    "Tm112",
    "Tm113",
    "Tm114",
    "Tm115",
    "Tm116",
    "Tm117",
    "Tm118",
    "Tm119",
    "Tm120",
    "Tm121",
    "Tm122",
    "Tm123",
    "Tm124",
    "Tm125",
    "Tm126",
    "Tm127",
    "Tm128",
    "Tm129",
    "Tm130",
    "Tm131",
    "Tm132",
    "Tm133",
    "Tm134",
    "Tm135",
    "Tm136",
    "Tm137",
    "Tm138",
    "Tm139",
    "Tm140",
    "Tm141",
    "Tm142",
    "Tm143",
    "Tm144",
    "Tm145",
    "Tm146",
    "Tm147",
    "Tm148",
    "Tm149",
    "Tm150",
    "Tm151",
    "Tm152",
    "Tm153",
    "Tm154",
    "Tm155",
    "Tm156",
    "Tm157",
    "Tm158",
    "Tm159",
    "Tm160",
    "Tm161",
    "Tm162",
    "Tm163",
    "Tm164",
    "Tm165",
    "Tm166",
    "Tm167",
    "Tm168",
    "Tm169",
    "Tm170",
    "Tm171",
    "Picnic Set",
    "Academy Bottle",
    "Polka Dot Bottle",
    "Striped Bottle",
    "Diamond Bottle",
    "Academy Cup",
    "Striped Cup",
    "Polka Dot Cup",
    "Flower Pattern Cup",
    "Academy Tablecloth",
    "Whimsical Tablecloth",
    "Leafy Tablecloth",
    "Spooky Tablecloth",
    "Academy Ball",
    "Marill Ball",
    "Yarn Ball",
    "Cyber Ball",
    "Gold Pick",
    "Silver Pick",
    "Red Flag Pick",
    "Blue Flag Pick",
    "Pika Pika Pick",
    "Winking Pika Pick",
    "Vee Vee Pick",
    "Smiling Vee Pick",
    "Blue Poke Ball Pick",
    "Auspicious Armor",
    "Leader’S Crest",
    "Pink Bottle",
    "Blue Bottle",
    "Yellow Bottle",
    "Steel Bottle (R)",
    "Steel Bottle (Y)",
    "Steel Bottle (B)",
    "Silver Bottle",
    "Barred Cup",
    "Diamond Pattern Cup",
    "Fire Pattern Cup",
    "Pink Cup",
    "Blue Cup",
    "Yellow Cup",
    "Pikachu Cup",
    "Eevee Cup",
    "Slowpoke Cup",
    "Silver Cup",
    "Exercise Ball",
    "Plaid Tablecloth (Y)",
    "Plaid Tablecloth (B)",
    "Plaid Tablecloth (R)",
    "B&W Grass Tablecloth",
    "Battle Tablecloth",
    "Monstrous Tablecloth",
    "Striped Tablecloth",
    "Diamond Tablecloth",
    "Polka Dot Tablecloth",
    "Lilac Tablecloth",
    "Mint Tablecloth",
    "Peach Tablecloth",
    "Yellow Tablecloth",
    "Blue Tablecloth",
    "Pink Tablecloth",
    "Gold Bottle",
    "Bronze Bottle",
    "Gold Cup",
    "Bronze Cup",
    "Green Poke Ball Pick",
    "Red Poke Ball Pick",
    "Party Sparkler Pick",
    "Heroic Sword Pick",
    "Magical Star Pick",
    "Magical Heart Pick",
    "Parasol Pick",
    "Blue Sky Flower Pick",
    "Sunset Flower Pick",
    "Sunrise Flower Pick",
    "Blue Dish",
    "Green Dish",
    "Orange Dish",
    "Red Dish",
    "White Dish",
    "Yellow Dish",
    "Roto Stick",
    "Teal Style Card",
    "Teal Mask",
    "Glimmering Charm",
    "Crystal Cluster",
    "Fairy Feather",
    "Wellspring Mask",
    "Hearthflame Mask",
    "Cornerstone Mask",
    "Syrupy Apple",
    "Unremarkable Teacup",
    "Masterpiece Teacup",
    "Health Mochi",
    "Muscle Mochi",
    "Resist Mochi",
    "Genius Mochi",
    "Clever Mochi",
    "Swift Mochi",
    "Fresh Start Mochi",
    "Ekans Fang",
    "Sandshrew Claw",
    "Cleffa Fur",
    "Vulpix Fur",
    "Poliwag Slime",
    "Bellsprout Vine",
    "Geodude Fragment",
    "Koffing Gas",
    "Munchlax Fang",
    "Sentret Fur",
    "Hoothoot Feather",
    "Spinarak Thread",
    "Aipom Hair",
    "Yanma Spike",
    "Gligar Fang",
    "Slugma Lava",
    "Swinub Hair",
    "Poochyena Fang",
    "Lotad Leaf",
    "Seedot Stem",
    "Nosepass Fragment",
    "Volbeat Fluid",
    "Illumise Fluid",
    "Corphish Shell",
    "Feebas Scales",
    "Duskull Fragment",
    "Chingling Fragment",
    "Timburr Sweat",
    "Sewaddle Leaf",
    "Ducklett Feather",
    "Litwick Soot",
    "Mienfoo Claw",
    "Vullaby Feather",
    "Carbink Jewel",
    "Phantump Twig",
    "Grubbin Thread",
    "Cutiefly Powder",
    "Jangmo O Scales",
    "Cramorant Down",
    "Morpeko Snack",
    "Poltchageist Powder",
    "Linking Cord",
    "Tm172",
    "Tm173",
    "Tm174",
    "Tm175",
    "Tm176",
    "Tm177",
    "Tm178",
    "Tm179",
    "Tm180",
    "Tm181",
    "Tm182",
    "Tm183",
    "Tm184",
    "Tm185",
    "Tm186",
    "Tm187",
    "Tm188",
    "Tm189",
    "Tm190",
    "Tm191",
    "Tm192",
    "Tm193",
    "Tm194",
    "Tm195",
    "Tm196",
    "Tm197",
    "Tm198",
    "Tm199",
    "Tm200",
    "Tm201",
    "Tm202",
    "Tm203",
    "Tm204",
    "Tm205",
    "Tm206",
    "Tm207",
    "Tm208",
    "Tm209",
    "Tm210",
    "Tm211",
    "Tm212",
    "Tm213",
    "Tm214",
    "Tm215",
    "Tm216",
    "Tm217",
    "Tm218",
    "Tm219",
    "Tm220",
    "Tm221",
    "Tm222",
    "Tm223",
    "Tm224",
    "Tm225",
    "Tm226",
    "Tm227",
    "Tm228",
    "Tm229",
    "Lastrange Ball",
    "Lapoke Ball",
    "Lagreat Ball",
    "Laultra Ball",
    "Laheavy Ball",
    "Laleaden Ball",
    "Lagigaton Ball",
    "Lafeather Ball",
    "Lawing Ball",
    "Lajet Ball",
    "Laorigin Ball",
    "Black Augurite",
    "Peat Block",
)

POKEMON_ITEM_CATEGORIES: tuple[str, ...] = (
    "Stat Boosts",
    "Effort Drop",
    "Medicine",
    "Other",
    "In A Pinch",
    "Picky Healing",
    "Type Protection",
    "Baking Only",
    "Collectibles",
    "Evolution",
    "Spelunking",
    "Held Items",
    "Choice",
    "Effort Training",
    "Bad Held Items",
    "Training",
    "Plates",
    "Species Specific",
    "Type Enhancement",
    "Event Items",
    "Gameplay",
    "Plot Advancement",
    "Unused",
    "Loot",
    "All Mail",
    "Vitamins",
    "Healing",
    "Pp Recovery",
    "Revival",
    "Status Cures",
    "Mulch",
    "Special Balls",
    "Standard Balls",
    "Dex Completion",
    "Scarves",
    "All Machines",
    "Flutes",
    "Apricorn Balls",
    "Apricorn Box",
    "Data Cards",
    "Jewels",
    "Miracle Shooter",
    "Mega Stones",
    "Memories",
    "Z Crystals",
    "Species Candies",
    "Catching Bonus",
    "Dynamax Crystals",
    "Nature Mints",
    "Curry Ingredients",
    "Tera Shard",
    "Sandwich Ingredients",
    "Tm Materials",
    "Picnic",
)

POKEMON_ABILITIES: tuple[str, ...] = (
    "Stench",
    "Drizzle",
    "Speed Boost",
    "Battle Armor",
    "Sturdy",
    "Damp",
    "Limber",
    "Sand Veil",
    "Static",
    "Volt Absorb",
    "Water Absorb",
    "Oblivious",
    "Cloud Nine",
    "Compound Eyes",
    "Insomnia",
    "Color Change",
    "Immunity",
    "Flash Fire",
    "Shield Dust",
    "Own Tempo",
    "Suction Cups",
    "Intimidate",
    "Shadow Tag",
    "Rough Skin",
    "Wonder Guard",
    "Levitate",
    "Effect Spore",
    "Synchronize",
    "Clear Body",
    "Natural Cure",
    "Lightning Rod",
    "Serene Grace",
    "Swift Swim",
    "Chlorophyll",
    "Illuminate",
    "Trace",
    "Huge Power",
    "Poison Point",
    "Inner Focus",
    "Magma Armor",
    "Water Veil",
    "Magnet Pull",
    "Soundproof",
    "Rain Dish",
    "Sand Stream",
    "Pressure",
    "Thick Fat",
    "Early Bird",
    "Flame Body",
    "Run Away",
    "Keen Eye",
    "Hyper Cutter",
    "Pickup",
    "Truant",
    "Hustle",
    "Cute Charm",
    "Plus",
    "Minus",
    "Forecast",
    "Sticky Hold",
    "Shed Skin",
    "Guts",
    "Marvel Scale",
    "Liquid Ooze",
    "Overgrow",
    "Blaze",
    "Torrent",
    "Swarm",
    "Rock Head",
    "Drought",
    "Arena Trap",
    "Vital Spirit",
    "White Smoke",
    "Pure Power",
    "Shell Armor",
    "Air Lock",
    "Tangled Feet",
    "Motor Drive",
    "Rivalry",
    "Steadfast",
    "Snow Cloak",
    "Gluttony",
    "Anger Point",
    "Unburden",
    "Heatproof",
    "Simple",
    "Dry Skin",
    "Download",
    "Iron Fist",
    "Poison Heal",
    "Adaptability",
    "Skill Link",
    "Hydration",
    "Solar Power",
    "Quick Feet",
    "Normalize",
    "Sniper",
    "Magic Guard",
    "No Guard",
    "Stall",
    "Technician",
    "Leaf Guard",
    "Klutz",
    "Mold Breaker",
    "Super Luck",
    "Aftermath",
    "Anticipation",
    "Forewarn",
    "Unaware",
    "Tinted Lens",
    "Filter",
    "Slow Start",
    "Scrappy",
    "Storm Drain",
    "Ice Body",
    "Solid Rock",
    "Snow Warning",
    "Honey Gather",
    "Frisk",
    "Reckless",
    "Multitype",
    "Flower Gift",
    "Bad Dreams",
    "Pickpocket",
    "Sheer Force",
    "Contrary",
    "Unnerve",
    "Defiant",
    "Defeatist",
    "Cursed Body",
    "Healer",
    "Friend Guard",
    "Weak Armor",
    "Heavy Metal",
    "Light Metal",
    "Multiscale",
    "Toxic Boost",
    "Flare Boost",
    "Harvest",
    "Telepathy",
    "Moody",
    "Overcoat",
    "Poison Touch",
    "Regenerator",
    "Big Pecks",
    "Sand Rush",
    "Wonder Skin",
    "Analytic",
    "Illusion",
    "Imposter",
    "Infiltrator",
    "Mummy",
    "Moxie",
    "Justified",
    "Rattled",
    "Magic Bounce",
    "Sap Sipper",
    "Prankster",
    "Sand Force",
    "Iron Barbs",
    "Zen Mode",
    "Victory Star",
    "Turboblaze",
    "Teravolt",
    "Aroma Veil",
    "Flower Veil",
    "Cheek Pouch",
    "Protean",
    "Fur Coat",
    "Magician",
    "Bulletproof",
    "Competitive",
    "Strong Jaw",
    "Refrigerate",
    "Sweet Veil",
    "Stance Change",
    "Gale Wings",
    "Mega Launcher",
    "Grass Pelt",
    "Symbiosis",
    "Tough Claws",
    "Pixilate",
    "Gooey",
    "Aerilate",
    "Parental Bond",
    "Dark Aura",
    "Fairy Aura",
    "Aura Break",
    "Primordial Sea",
    "Desolate Land",
    "Delta Stream",
    "Stamina",
    "Wimp Out",
    "Emergency Exit",
    "Water Compaction",
    "Merciless",
    "Shields Down",
    "Stakeout",
    "Water Bubble",
    "Steelworker",
    "Berserk",
    "Slush Rush",
    "Long Reach",
    "Liquid Voice",
    "Triage",
    "Galvanize",
    "Surge Surfer",
    "Schooling",
    "Disguise",
    "Battle Bond",
    "Power Construct",
    "Corrosion",
    "Comatose",
    "Queenly Majesty",
    "Innards Out",
    "Dancer",
    "Battery",
    "Fluffy",
    "Dazzling",
    "Soul Heart",
    "Tangling Hair",
    "Receiver",
    "Power Of Alchemy",
    "Beast Boost",
    "Rks System",
    "Electric Surge",
    "Psychic Surge",
    "Misty Surge",
    "Grassy Surge",
    "Full Metal Body",
    "Shadow Shield",
    "Prism Armor",
    "Neuroforce",
    "Intrepid Sword",
    "Dauntless Shield",
    "Libero",
    "Ball Fetch",
    "Cotton Down",
    "Propeller Tail",
    "Mirror Armor",
    "Gulp Missile",
    "Stalwart",
    "Steam Engine",
    "Punk Rock",
    "Sand Spit",
    "Ice Scales",
    "Ripen",
    "Ice Face",
    "Power Spot",
    "Mimicry",
    "Screen Cleaner",
    "Steely Spirit",
    "Perish Body",
    "Wandering Spirit",
    "Gorilla Tactics",
    "Neutralizing Gas",
    "Pastel Veil",
    "Hunger Switch",
    "Quick Draw",
    "Unseen Fist",
    "Curious Medicine",
    "Transistor",
    "Dragons Maw",
    "Chilling Neigh",
    "Grim Neigh",
    "As One Glastrier",
    "As One Spectrier",
    "Lingering Aroma",
    "Seed Sower",
    "Thermal Exchange",
    "Anger Shell",
    "Purifying Salt",
    "Well Baked Body",
    "Wind Rider",
    "Guard Dog",
    "Rocky Payload",
    "Wind Power",
    "Zero To Hero",
    "Commander",
    "Electromorphosis",
    "Protosynthesis",
    "Quark Drive",
    "Good As Gold",
    "Vessel Of Ruin",
    "Sword Of Ruin",
    "Tablets Of Ruin",
    "Beads Of Ruin",
    "Orichalcum Pulse",
    "Hadron Engine",
    "Opportunist",
    "Cud Chew",
    "Sharpness",
    "Supreme Overlord",
    "Costar",
    "Toxic Debris",
    "Armor Tail",
    "Earth Eater",
    "Mycelium Might",
    "Minds Eye",
    "Supersweet Syrup",
    "Hospitality",
    "Toxic Chain",
    "Embody Aspect",
    "Tera Shift",
    "Tera Shell",
    "Teraform Zero",
    "Poison Puppeteer",
    "Mountaineer",
    "Wave Rider",
    "Skater",
    "Thrust",
    "Perception",
    "Parry",
    "Instinct",
    "Dodge",
    "Jagged Edge",
    "Frostbite",
    "Tenacity",
    "Pride",
    "Deep Sleep",
    "Power Nap",
    "Spirit",
    "Warm Blanket",
    "Gulp",
    "Herbivore",
    "Sandpit",
    "Hot Blooded",
    "Medic",
    "Life Force",
    "Lunchbox",
    "Nurse",
    "Melee",
    "Sponge",
    "Bodyguard",
    "Hero",
    "Last Bastion",
    "Stealth",
    "Vanguard",
    "Nomad",
    "Sequence",
    "Grass Cloak",
    "Celebrate",
    "Lullaby",
    "Calming",
    "Daze",
    "Frighten",
    "Interference",
    "Mood Maker",
    "Confidence",
    "Fortune",
    "Bonanza",
    "Explode",
    "Omnipotent",
    "Share",
    "Black Hole",
    "Shadow Dash",
    "Sprint",
    "Disgust",
    "High Rise",
    "Climber",
    "Flame Boost",
    "Aqua Boost",
    "Run Up",
    "Conqueror",
    "Shackle",
    "Decoy",
    "Shield",
)

POKEMON_NATURES: tuple[str, ...] = (
    "Hardy",
    "Bold",
    "Modest",
    "Calm",
    "Timid",
    "Lonely",
    "Docile",
    "Mild",
    "Gentle",
    "Hasty",
    "Adamant",
    "Impish",
    "Bashful",
    "Careful",
    "Rash",
    "Jolly",
    "Naughty",
    "Lax",
    "Quirky",
    "Naive",
    "Brave",
    "Relaxed",
    "Quiet",
    "Sassy",
    "Serious",
)

POKEMON_BERRIES: tuple[str, ...] = (
    "Cheri",
    "Chesto",
    "Pecha",
    "Rawst",
    "Aspear",
    "Leppa",
    "Oran",
    "Persim",
    "Lum",
    "Sitrus",
    "Figy",
    "Wiki",
    "Mago",
    "Aguav",
    "Iapapa",
    "Razz",
    "Bluk",
    "Nanab",
    "Wepear",
    "Pinap",
    "Pomeg",
    "Kelpsy",
    "Qualot",
    "Hondew",
    "Grepa",
    "Tamato",
    "Cornn",
    "Magost",
    "Rabuta",
    "Nomel",
    "Spelon",
    "Pamtre",
    "Watmel",
    "Durin",
    "Belue",
    "Occa",
    "Passho",
    "Wacan",
    "Rindo",
    "Yache",
    "Chople",
    "Kebia",
    "Shuca",
    "Coba",
    "Payapa",
    "Tanga",
    "Charti",
    "Kasib",
    "Haban",
    "Colbur",
    "Babiri",
    "Chilan",
    "Liechi",
    "Ganlon",
    "Salac",
    "Petaya",
    "Apicot",
    "Lansat",
    "Starf",
    "Enigma",
    "Micle",
    "Custap",
    "Jaboca",
    "Rowap",
)

POKEMON_COMPANIES: tuple[str, ...] = (
    "Silph Co.",
    "Devon Corporation",
    "Lysandre Labs",
    "Macro Cosmos",
    "Aether Foundation",
    "Team Rocket Corporation",
    "Pokemon Fan Club",
    "Global Trade Station",
    "Poketch Company",
    "Battle Company",
    "Castelia Cone",
    "LPokemon",
    "Pokestar Studios",
    "Lumiose Press",
    "Mauville Game Corner",
    "Galactic Energy",
    "Future Industries",
    "Rose Tower Corp.",
    "Treasure Town Guild",
    "Ranger Union",
)

POKEMON_COMPANY_SUFFIXES: tuple[str, ...] = (
    "Co.",
    "Corp.",
    "Corporation",
    "Labs",
    "Foundation",
    "Industries",
    "Inc.",
    "Group",
    "Guild",
    "Union",
)

POKEMON_STREET_SUFFIXES: tuple[str, ...] = (
    "Road",
    "Route",
    "Path",
    "Trail",
    "Avenue",
    "Way",
    "Lane",
    "Bridge",
    "Tunnel",
    "Pass",
)

